<?php
if ( !defined('ABSPATH')) exit; // Exit if accessed directly
/**
 * Aspen functions and definitions
 *
 *	>>>> DO NOT EDIT THIS FILE <<<<
 *
 * Warning! DO NOT EDIT THIS FILE, or any other theme file! If you edit ANY theme
 * file, all your changes will be LOST when you update the theme to a newer version.
 * Instead, if you need to change theme functionality, CREATE A CHILD THEME!
 *
 *	>>>> DO NOT EDIT THIS FILE <<<<
 *
 * Sets up the theme and provides some helper functions. Some helper functions
 * are used in the theme as custom template tags. Others are attached to action and
 * filter hooks in WordPress to change core functionality.
 *
 * The first function, aspen_setup(), sets up the theme by registering support
 * for various features in WordPress, such as post thumbnails, navigation menus, and the like.
 *
 * When using a child theme (see http://codex.wordpress.org/Theme_Development and
 * http://codex.wordpress.org/Child_Themes), you can override certain functions
 * (those wrapped in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before the parent
 * theme's file, so the child theme functions would be used.
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are instead attached
 * to a filter or action hook. The hook can be removed by using remove_action() or
 * remove_filter() and you can attach your own function to the hook.
 *
 * We can remove the parent theme's hook only after it is attached, which means we need to
 * wait until setting up the child theme:
 *
 * <code>
 * add_action( 'after_setup_theme', 'my_child_theme_setup' );
 * function my_child_theme_setup() {
 *     // We are providing our own filter for excerpt_length (or using the unfiltered value)
 *     remove_filter( 'excerpt_length', 'aspen_excerpt_length' );
 *     ...
 * }
 * </code>
 *
 * For more information on hooks, actions, and filters, see http://codex.wordpress.org/Plugin_API.
 *
 * @package WordPress
 * @subpackage Aspen
 * @since Aspen 1.0
 *
 * This file formatted 4/8 on tabs
 *
 *	>>>> DO NOT EDIT THIS FILE <<<<
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) )
	$content_width = 705;   // 940 * .75

/**
 * Tell WordPress to run aspen_setup() when the 'after_setup_theme' hook is run.
 */
add_action( 'after_setup_theme', 'aspen_setup' );

if ( ! function_exists( 'aspen_setup' ) ) {
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 *
 * To override aspen_setup() in a child theme, add your own aspen_setup to your child theme's
 * functions.php file.
 *
 * @uses load_theme_textdomain() For translation/localization support.
 * @uses add_editor_style() To style the visual editor.
 * @uses add_theme_support() To add support for post thumbnails, automatic feed links, and Post Formats.
 * @uses register_nav_menus() To add support for navigation menus.
 * @uses register_default_headers() To register the default custom header images provided with the theme.
 * @uses set_post_thumbnail_size() To set a custom post thumbnail size.
 *
 * @since Aspen 1.0
 *
 * @uses add_theme_support( 'custom-header', $aspen_header ) for WP 3.4+ custom header
 */
function aspen_setup() {

	/* Make Aspen available for translation. */

	$tpath = trailingslashit(get_template_directory());

	load_theme_textdomain( 'aspen', $tpath . 'languages' );

	$locale = get_locale();
	$locale_file = $tpath . "languages/$locale.php";
	if ( is_readable( $locale_file ) )
		require_once( $locale_file );

	// This theme styles the visual editor with editor-style.css to match the theme style.
	add_editor_style();

	// Add default posts and comments RSS feed links to <head>.
	add_theme_support( 'automatic-feed-links' );

	// Aspen supports two main nav menus and an alternate mobile menu
	register_nav_menus( array(
		'primary' => 'Primary Navigation: if specified, used instead of Default menu',
		'secondary' => 'Secondary Navigation: if specified, adds 2nd menu bar'
	) );

	// Add support for a variety of post formats
	add_theme_support( 'post-formats', array( 'aside', 'audio', 'chat', 'gallery',  'image', 'link', 'quote', 'status','video') );

	// This theme uses Featured Images (also known as post thumbnails) for per-post/per-page Custom Header images
	add_theme_support( 'post-thumbnails' );

	// now, need Aspen settings available for everything else

	aspen_init_opts('functions');

	$width = aspen_getopt('theme_width_int');
	if (!$width)
		$width = 940;
	$height = aspen_getopt('header_image_height_int');

	global $aspen_header;
	$aspen_header = array(
		'default-image' => '%s/images/headers/maroon-bells.jpg',
		'random-default' => true,
		'width' => $width,
		'height' => $height,
		'flex-height' => true,
		'flex-width' => true,
		'default-text-color' => '',
		'header-text' => false,
		'uploads' => true,
		'wp-head-callback' => '',
		'admin-head-callback' => 'aspen_admin_header_style',
		'admin-preview-callback' => '',
	);

		global $content_width;
		$content_width = $width;    // let the WP $content_width be the same as theme width, and let our responsive CSS make it work.


	if (function_exists('get_custom_header')) {
		add_theme_support( 'custom-header', $aspen_header );
		add_theme_support( 'custom-background' );
	}

	// We'll be using post thumbnails for custom header images on posts and pages.
	// We want them to be the size of the header image that we just defined
	// Larger images will be auto-cropped to fit, smaller ones will be ignored. See header.php.
	set_post_thumbnail_size( $aspen_header['width'], $aspen_header['height'], true );

	// Add Aspen's custom image sizes
	add_image_size( 'large-feature',
		$aspen_header['width'], $aspen_header['height'], true ); // Used for large feature (header) images
	add_image_size( 'small-feature', 500, 300 ); // Used for featured posts if a large-feature doesn't exist


	// ... and thus ends the changeable header business.
	aspen_register_header_images();
}
} // aspen_setup


function aspen_admin_init_cb() {	// action definition

	aspen_sapi_options_init(); // This must come first as it hooks update_option used elsewhere
	return;
}

if ( ! function_exists('aspen_init_opts')) {
function aspen_init_opts($who='') {
	// this sets either the current settings, or the default values.

    $themename = aspen_getopt('themename'); // load the theme from the db if there
    if ($themename === false) {
        require_once('includes/get-default-settings.php');  // load a set of defaults
        aspen_get_default_settings();
    }

	do_action('aspen_init_opts');
}
}

if (! function_exists( 'aspen_register_header_images')) {
function aspen_register_header_images() {
	// Default custom headers packaged with the theme. %s is a placeholder for the theme template directory URI.
	register_default_headers( array(

	'maroon-bells' => array(
		'url' => '%s/images/headers/maroon-bells.jpg',
		'thumbnail_url' => '%s/images/headers/maroon-bells-thumbnail.jpg',
		/* translators: header image description */
		'description' => aspen_t_( 'Maroon Bells' /*a*/ )
		),
	'aspen-grove' => array (
		'url' => "%s/images/headers/aspen-grove.jpg",
		'thumbnail_url' => "%s/images/headers/aspen-grove-thumbnail.jpg",
		'description' => aspen_t_( 'Aspen Grove' /*a*/ )
		),
	'mountain-stream' => array(
		'url' => '%s/images/headers/mountain-stream.jpg',
		'thumbnail_url' => '%s/images/headers/mountain-stream-thumbnail.jpg',
		/* translators: header image description */
		'description' => aspen_t_( 'Mountain Stream' /*a*/ )
		),
	'mum' => array (
		'url' => "%s/images/headers/mum.jpg",
		'thumbnail_url' => "%s/images/headers/mum-thumbnail.jpg",
		'description' => aspen_t_( 'Mum' /*a*/ )
		),
	'sopris' => array (
		'url' => "%s/images/headers/sopris.jpg",
		'thumbnail_url' => "%s/images/headers/sopris-thumbnail.jpg",
		'description' => aspen_t_( 'Sopris' /*a*/ )
		)
	) );
}
}

if ( ! function_exists( 'aspen_header_style' ) ) {
/**
 * Styles the header image and text displayed on the blog
 *
 * @since Aspen 1.0s
 */
function aspen_header_style() {
	// we don't need to do anything
}
} // aspen_header_style

if ( ! function_exists( 'aspen_admin_header_style' ) ) {
/**
 * Styles the header image displayed on the Appearance > Header admin panel.
 * @since Aspen 1.0
 */
function aspen_admin_header_style() {
	global $aspen_header;
?>
	<style type="text/css">
	#headimg img {
		width: <?php echo $aspen_header['width']; ?>px;
		height: auto;
		width: 100%;
	}
	</style>
<?php
}
} // aspen_admin_header_style

function aspen_featured_image_info($text) {
	return $text .
'<p><small>Featured Images at least as wide as default header image will be used as a replacement for default image for this page or post. Smaller images used as "thumbnail" at beginning of Page/Post.</small></p>';

}
add_filter('admin_post_thumbnail_html','aspen_featured_image_info');


/**
 * Sets the post excerpt length to 40 words.
 *
 * To override this length in a child theme, remove the filter and add your own
 * function tied to the excerpt_length filter hook.
 */
function aspen_excerpt_length( $length ) {
	$val = aspen_t_get('excerpt_length');
	if (!$val)
		$val = aspen_getopt('excerpt_length');
	if ($val > 0 || $val === '0')
		return $val;
	return 40;
}
add_filter( 'excerpt_length', 'aspen_excerpt_length' );

/**
 * Returns a "Continue Reading" link for excerpts
 */
if ( ! function_exists('aspen_continue_reading_link')) {
function aspen_continue_reading_link($add_a = true) {

	$rep = aspen_t_get('more_msg');
	if (!$rep)
		$rep = aspen_getopt('excerpt_more_msg');

	if (!empty($rep))
		$msg = $rep;
	else
		$msg = __( 'Continue reading <span class="meta-nav">&rarr;</span>','aspen');

	if ($add_a)
		return ' <a class="more-link" href="'. esc_url(get_permalink()) . '">' . $msg . '</a>';
	else
		return $msg;
}
}

/**
 * Replaces "[...]" (appended to automatically generated excerpts) with an ellipsis and aspen_continue_reading_link().
 *
 * To override this in a child theme, remove the filter and add your own
 * function tied to the excerpt_more filter hook.
 */
function aspen_auto_excerpt_more( $more ) {
	return ' &hellip;' . aspen_continue_reading_link();
}
add_filter( 'excerpt_more', 'aspen_auto_excerpt_more' );

/**
 * Adds a pretty "Continue Reading" link to custom post excerpts.
 *
 * To override this link in a child theme, remove the filter and add your own
 * function tied to the get_aspen_the_excerpt_featured filter hook.
 */

function aspen_custom_excerpt_more( $output ) {
	if ( has_excerpt() && !is_attachment() ) {
		$output .= aspen_continue_reading_link();
	}
	return $output;
}
add_filter( 'the_excerpt', 'aspen_custom_excerpt_more' );

if ( ! function_exists('aspen_trim_excerpt') ) {
	function aspen_trim_excerpt($text = '') {
	$raw_excerpt = $text;
	if ( '' == $text ) {
		$text = get_the_content('');
		$orig_text_len = strlen($text);

		$text = strip_shortcodes( $text );
		// $stripped_text_len = strlen($text);

		$text = apply_filters('the_content', $text);
		$text = str_replace(']]>', ']]&gt;', $text);
		$excerpt_length = apply_filters('excerpt_length', 55);
		$excerpt_more = apply_filters('excerpt_more', ' ' . '[...]');
		$text = wp_trim_words( $text, $excerpt_length, $excerpt_more );
		$stripped_text_len = strlen($text);
	}
	if ('' == $raw_excerpt && $orig_text_len > $stripped_text_len && get_post_format() == '') {	// have stripped shortcodes
		if ( strpos($text,$excerpt_more) === false)
			$text .= $excerpt_more;
	}
	return apply_filters('wp_trim_excerpt', $text, $raw_excerpt);
}
}
remove_filter( 'get_the_excerpt', 'wp_trim_excerpt'  );
add_filter( 'get_the_excerpt', 'aspen_trim_excerpt'  );

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 *
 * To override this in a child theme, remove the filter and optionally add
 * your own function tied to the wp_page_menu_args filter hook.
 */
function aspen_page_menu_args( $args ) {
	if (aspen_getopt('menu_nohome'))
		$args['show_home'] = false;
	else
		$args['show_home'] = true;

	// look for pages to hide from menu
	$ex_list = '';
	$hide_pages = get_pages(array('hierarchical' => 0, 'meta_key' => 'pp_hide_on_menu'));	// get list of excluded pages
	if (!empty($hide_pages)) {
		foreach ($hide_pages as $page) {
			$ex_list .= $page->ID . ',';	/* trailing , doesn't matter */
		}
	}


	if ($ex_list != '')
		$args['exclude'] = $ex_list;
	return $args;
}
add_filter( 'wp_page_menu_args', 'aspen_page_menu_args' );

/**
 * Register our sidebars and widgetized areas.
 *
 * @since Aspen 1.0
 */
function aspen_widgets_init() {

	// Big Top located at the top of the sidebar.
	aspen_register_sidebar( aspen_t_( 'Primary (top) Sidebar' /*a*/ ),
		'primary-widget-area',
		aspen_t_( 'Primary (top) sidebar widget area, displays above Upper Sidebar (or Left+Right for multi-column layouts).' /*a*/    ));

	// Primary located at the top of the sidebar.
	aspen_register_sidebar( aspen_t_( 'Upper/Right Sidebar' /*a*/ ),
		'right-widget-area', aspen_t_( 'The Upper Sidebar - or Right Sidebar for multi-column layouts.' /*a*/ ));

	// Lower/Left located below the Primary Widget Area in the sidebar. Empty by default.
	aspen_register_sidebar( aspen_t_( 'Lower/Left Sidebar' /*a*/ ),
		'left-widget-area', aspen_t_( 'The Lower Sidebar - or Left Sidebar for multi-column layouts.' /*a*/ ));

		// Mobile device
	aspen_register_sidebar(aspen_t_( 'Mobile Device Widget Area' /*a*/ ),
		'mobile-widget-area',
		 aspen_t_( 'This widget area provides an alternate area for Mobile Devices. It is displayed between the content and the footer, and uses the same styling as the Primary (top) Sidebar.' /*a*/ ));

		## Site-wide top area
	aspen_register_sidebar(aspen_t_( 'Sitewide Top Widget Area' /*a*/ ),
		'sitewide-top-widget-area',
		 aspen_t_( 'This widget area appears at the top of the content area on all site static pages and post pages (including special post pages) EXCEPT pages using the blank or iframe page templates.' /*a*/ ));

	## Site-wide bottom area
	aspen_register_sidebar(aspen_t_( 'Sitewide Bottom Widget Area' /*a*/ ),
		'sitewide-bottom-widget-area',
		aspen_t_( 'This widget area appears at the bottom of the content area on all site static pages and post pages (including special post pages) EXCEPT pages using the blank or iframe page templates.' /*a*/ ));

	## page top widget area
	aspen_register_sidebar(aspen_t_( 'Pages Top Widget Area' /*a*/ ),
		'top-widget-area',
		 aspen_t_( 'The top widget area appears above the content area of pages. It is not displayed on archive-like post pages (archives, etc.).' /*a*/ ));

	## page bottom widget area
	aspen_register_sidebar(aspen_t_( 'Pages Bottom Widget Area' /*a*/ ),
		'bottom-widget-area', aspen_t_( 'The bottom widget area appears below the content area. It is not displayed on archive-like post pages.' /*a*/ ));

	## posts top widget area
	aspen_register_sidebar(aspen_t_( 'Blog Top Widget Area' /*a*/ ),
		'blog-top-widget-area',
		 aspen_t_( 'The blog top widget area appears above the content area of blog pages, including page with posts templates. It is not displayed on archive-like post pages.' /*a*/ ));

	## posts blog bottom widget area
	aspen_register_sidebar(aspen_t_( 'Blog Bottom Widget Area' /*a*/ ),
		'blog-bottom-widget-area', aspen_t_( 'The blog bottom widget area appears below the content area of blog pages, including page with posts templates. It is not displayed on archive-like post pages.' /*a*/ ));


	## Special Post Pages Top Widget area
	aspen_register_sidebar(aspen_t_( 'Archive-like Pages Top Widget Area' /*a*/ ),
		'postpages-widget-area',
		aspen_t_( 'This widget area will appear at the top of archive-like post pages (archives, attachment, author, category, single post).' /*a*/ ));


	// Area 3, located in the footer. Empty by default.
	aspen_register_sidebar( aspen_t_( 'First Footer Widget Area' /*a*/ ),
		'first-footer-widget-area',
		 aspen_t_( 'The first footer widget area. Note: Footer widget areas auto-adujust width depending on how many areas you use.' /*a*/ ));

	// Area 4, located in the footer. Empty by default.
	aspen_register_sidebar(aspen_t_( 'Second Footer Widget Area' /*a*/ ),
		'second-footer-widget-area',
		aspen_t_( 'The second footer widget area' /*a*/ ));

	// Area 5, located in the footer. Empty by default.
	aspen_register_sidebar(aspen_t_( 'Third Footer Widget Area' /*a*/ ),
		'third-footer-widget-area',
		aspen_t_( 'The third footer widget area' /*a*/ ));

	aspen_register_sidebar(aspen_t_( 'Fourth Footer Widget Area' /*a*/ ),
		'fourth-footer-widget-area',
		aspen_t_( 'The fourth footer widget area' /*a*/ ));

}

add_action( 'widgets_init', 'aspen_widgets_init' );

if ( ! function_exists('aspen_register_sidebar')) {
/**
 * Register widgetized areas: two default sidebars, two content areq sidebars,
 * a top area for specialized post pages, alternative sidebar for template pages,
 * and a header widget area.
 *
 * To override aspen_widgets_init() in a child theme, remove the action hook and add your own
 * function tied to the init hook.
 *
 * @uses register_sidebar
 */
function aspen_register_sidebar($name, $id, $desc, $altclass='') {
	if ($altclass != '') $altclass .= ' ';
	register_sidebar( array(
		'name' => '&#149; ' . $name,	/* the &#149; makes our names closer to unique */
		'id' => $id,
		'description' => $desc,
		'before_widget' => '<aside id="%1$s" class="widget ' . $altclass . '%2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
}
}

if ( ! function_exists('aspen_inject_area')) {
function aspen_inject_area($name) {
	$area_name = '' . $name . '_insert';
	$hide_front = 'hide_front_' . $name;
	$hide_rest = 'hide_rest_' . $name;

    if ( aspen_getopt_checked( $hide_front ) && is_front_page() )
        return;
    if ( aspen_getopt_checked( $hide_rest ) && !is_front_page() )
        return;

	$idinj = 'inject_' . $name;
	$html = apply_filters('aspen_inject_area', aspen_getopt($area_name), $name);
	$per_page_code = apply_filters('aspen_inject_area', aspen_get_per_page_value($name), $name);	/* per page values */

	if (!empty($html) || !empty($per_page_code)) {
		if ($name !='postpostcontent')
			echo("\t<div id=\"$idinj\">\n");
		else
			echo("\t<div class=\"$idinj\">\n");
		if (!empty($html)) {	/* area insert defined? */
			if (is_front_page()) {
		aspen_e_notopt($hide_front,do_shortcode($html));
			} else  {
				aspen_e_notopt($hide_rest,do_shortcode($html));
			}
		}
		if (!empty($per_page_code)) {
			echo(do_shortcode($per_page_code));
		}
		echo("\t</div><!-- #$idinj -->\n");
	}
}
}

if ( ! function_exists('aspen_content_nav')) {
/**
 * Display navigation to next/previous pages when applicable
 */
function aspen_content_nav( $nav_id , $from_search=false) {
	global $wp_query;

	if ( $wp_query->max_num_pages > 1 ) {
?>
	<nav id="<?php echo $nav_id; ?>">
		<h3 class="assistive-text"><?php echo __( 'Post navigation','aspen'); ?></h3>
<?php
	if (aspen_getopt('nav_style') == 'prev_next') {
?>
		<div class="nav-previous"><?php next_posts_link('<span class="meta-nav">&larr; </span>' . __('Previous Post','aspen')); ?></div>
		<div class="nav-next"><?php previous_posts_link( __('Next Post','aspen') . '<span class="meta-nav">&rarr; </span>'); ?></div>
<?php
	} else if (aspen_getopt('nav_style') == 'paged_left') {
		echo ("\t<div class=\"nav-previous\">");
		if (function_exists ('wp_pagenavi')) {
			wp_pagenavi();
		} else if ( function_exists( 'wp_paginate' ) ) {
			wp_paginate( 'title=' );
		} else {
			echo aspen_get_paginate_archive_page_links( 'plain',2,3 );
		}
		echo "\t</div>\n";
	} else if (aspen_getopt('nav_style') == 'paged_right') {
		echo ("\t<div class=\"nav-next\">");
		if (function_exists ('wp_pagenavi')) {
			wp_pagenavi();
		} else if ( function_exists( 'wp_paginate' ) ) {
			wp_paginate( 'title=' );
		} else {
			echo aspen_get_paginate_archive_page_links( 'plain',2,3 );
		}
		echo "\t</div>\n";
	} else {	// Older/Newer posts
?>
		<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts','aspen') ); ?></div>
		<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>','aspen') ); ?></div>
<?php	} ?>
	</nav><div class="aspen-clear"></div><!-- #<?php echo $nav_id;?> -->
<?php
	}
}
}

/**
 * Return the URL for the first link found in the post content.
 *
 * @since Aspen 1.0
 * @return string|bool URL or false when no link is present.
 */
if ( ! function_exists('aspen_url_grabber')) {
function aspen_url_grabber() {
	if ( ! preg_match( '/<a\s[^>]*?href=[\'"](.+?)[\'"]/is', get_the_content(), $matches ) )
		return false;

	return esc_url_raw( $matches[1] );
}
}

/**
 * Count the number of footer sidebars to enable dynamic classes for the footer
 */
if ( ! function_exists('aspen_footer_sidebar_class')) {
function aspen_footer_sidebar_class() {
	$count = 0;

	if ( is_active_sidebar( 'first-footer-widget-area' ) )
		$count++;
	if ( is_active_sidebar( 'second-footer-widget-area' ) )
		$count++;
	if ( is_active_sidebar( 'third-footer-widget-area' ) )
		$count++;
	if ( is_active_sidebar( 'fourth-footer-widget-area' ) )
		$count++;

	$class = '';
	switch ( $count ) {
		case '1':
			$class = 'one';
			break;
		case '2':
			$class = 'two';
			break;
		case '3':
			$class = 'three';
			break;
		case '4':
			$class = 'four';
			break;
	}
	if ( $class )
		echo 'class="' . $class . '"';
}
}

if ( ! function_exists( 'aspen_comment' ) ) {
/**
 * Template for comments and pingbacks.
 *
 * To override this walker in a child theme without modifying the comments template
 * simply create your own aspen_comment(), and that function will be used instead.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since Aspen 1.0
 */
function aspen_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;

	switch ( $comment->comment_type ) {
		case 'pingback' :
		case 'trackback' :
?>
	<li class="pingback">
		<p><?php echo __( 'Pingback:','aspen'); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( 'Edit','aspen'), '<span class="edit-link">', '</span>' ); ?></p>
<?php
			break;

		default :
?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>" >
		<article id="comment-<?php comment_ID(); ?>" class="comment">
			<footer class="comment-meta">
				<div class="comment-author vcard">
<?php
				$avatar_size = 40;
				if ( '0' != $comment->comment_parent )
					$avatar_size = 32;

				echo get_avatar( $comment, $avatar_size );

				/* translators: 1: comment author, 2: date and time */
				printf( __( '%1$s on %2$s <span class="says">said:</span>','aspen'),
					sprintf( '<span class="fn">%s</span>', get_comment_author_link() ),
					sprintf( '<a href="%1$s"><time datetime="%2$s">%3$s</time></a>',
					esc_url( get_comment_link( $comment->comment_ID ) ),
					get_comment_time( 'c' ),
					/* translators: 1: date, 2: time */
					sprintf( __( '%1$s at %2$s','aspen'), get_comment_date(), get_comment_time() )
					)
				);

			   edit_comment_link( __( 'Edit','aspen'), '<span class="edit-link">', '</span>' ); ?>
				</div><!-- .comment-author .vcard -->

				<?php if ( $comment->comment_approved == '0' ) : ?>
					<em class="comment-awaiting-moderation"><?php echo __( 'Your comment is awaiting moderation.','aspen'); ?></em>
					<br />
				<?php endif; ?>

			</footer>

			<div class="comment-content"><?php comment_text(); ?></div>
<?php
			$rl = get_comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply <span>&darr;</span>','aspen'), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) );
			if ($rl != '') {
?>
			<div class="reply">
				<?php echo $rl; ?>
			</div><!-- .reply -->
<?php
			}
?>
		</article><!-- #comment-## -->

	<?php
			break;
	} /* end switch */
}
} // ends check for aspen_comment()

// ===================================== Aspen Page / Post utils ============================
if ( !function_exists( 'aspen_edit_link')) {
function aspen_edit_link($echo = 'echo') {
	$before = '<span class="edit-link">';
	$after = '</span>';
	$link = __( 'Edit','aspen');
	$id = 0;

	if ( !$post = get_post( $id ) )
	return;

	if ( !$url = get_edit_post_link( $post->ID ) )
	return;

	$post_type_obj = get_post_type_object( $post->post_type );
	$link = '<a class="post-edit-link" href="' . $url . '" title="' . esc_attr( $post_type_obj->labels->edit_item ) . '">' . $link . '</a>';
	$edit = $before . apply_filters( 'edit_post_link', $link, $post->ID ) . $after;
	if ('echo' == $echo)
		echo $edit;
	else
		return $edit;
}
}

if ( !function_exists( 'aspen_link_pages')) {
function aspen_link_pages() {
	wp_link_pages( array( 'before' => '<div class="page-link"><span>' . __( 'Pages:','aspen') . '</span>', 'after' => '</div>' ) );
}
}

// ===================================== Aspen Page / Post Sections =========================

// for pages...

if ( !function_exists( 'aspen_page_title')) {
function aspen_page_title() {
	// The page title
?>
	<header class="entry-header<?php aspen_hide_page_title(); ?>">
	<h1 class="entry-title"><?php the_title(); ?></h1>
	</header><!-- .entry-header -->
<?php
}
}

if ( ! function_exists( 'aspen_entry_header' ) ) {
/**
 * Prints the entry-header (title)
 *
 * @since Aspen 1.0
 */
function aspen_entry_header($format_title='') {
	/* display entery header for posts */
?>
		<div class="entry-hdr">
<?php

	if ( $format_title != '' && ! aspen_is_checked_post_opt('pp_hide_post_format_label' ) )
		echo "\t\t\t\t<h3 class=\"entry-format\">" . $format_title . "</h3>\n";

	aspen_post_title('<h2 class="entry-title">', '</h2>');
?>
		</div>
<?php
}
}

if ( ! function_exists( 'aspen_post_title' ) ) {
// display the post title
function aspen_post_title($before='', $after='', $single = '') {

	if (aspen_is_checked_post_opt('pp_hide_post_title') || aspen_t_get('hide_title')) return;

	if ($single != 'single' && aspen_is_checked_post_opt('pp_favorite_post')) {
		$before = $before . sprintf("<img class=\"post-fav-star\" src=\"%s\" alt=\"Favorite\" />", esc_url(aspen_relative_url('images/icons/yellow-star.png')));
	}
	if ( ( 'page' == get_post_type() && !is_search() && !is_archive())
	|| $single == 'single') {
		echo("\t\t" . $before); the_title();
	} else {
		echo("\t\t" . $before);
?>
	<a href="<?php esc_url(the_permalink()); ?>" title="<?php printf( esc_attr(__( 'Permalink to %s','aspen')),
	   the_title_attribute( 'echo=0' ) ); ?>" rel="bookmark"><?php the_title(); ?></a>
<?php

	}

	if ( (aspen_getopt('show_post_avatar')
			|| aspen_is_checked_post_opt('pp_show_post_avatar')
			|| aspen_t_get('show_avatar'))
		&& !aspen_getopt('show_tiny_avatar')
	   ) {
?>
		<div class="post-avatar post-avatar-normal">
		<?php echo(get_avatar( get_the_author_meta('user_email') ,44,null,'avatar')); ?>
		</div>
<?php
	}
	echo($after . "\n");
}
} // if aspen_post_title

if ( ! function_exists('aspen_chat_title')) {
	function aspen_chat_title() {
?>
	<a href="<?php esc_url(the_permalink()); ?>" title="<?php printf( esc_attr( __( 'Permalink to %s','aspen')),
	   the_title_attribute( 'echo=0' ) ); ?>" rel="bookmark"><img class='format-chat-icon' src="<?php echo esc_url(aspen_relative_url('images/icons/chat.png')); ?>" alt='chat' /></a>
			<?php the_author(); ?>:&nbsp;<span class="entry-meta aspen-author-chat">
<?php			printf('<a href="%s" title="Chat" rel="bookmark"><time class="entry-date" datetime="%s">%s</time></a> - %s',
				esc_url( get_permalink() ), esc_attr( get_the_date( 'c' ) ), esc_html( get_the_date() ), esc_attr( get_the_time() ));
?>
			</span>
<?php
	}
}

if ( ! function_exists( 'aspen_posted_on' ) ) {
/**
 * Prints HTML with meta information for the current post-date/time and author.
 * Create your own aspen_posted_on to override in a child theme
 *
 * @since Aspen 1.0
 */
function aspen_posted_on($type='') {

	if (aspen_getopt_checked('post_info_hide_top')
		|| aspen_is_checked_post_opt('pp_hide_top_post_meat')
	|| aspen_is_checked_page_opt('pp_hide_infotop')
		|| aspen_t_get('hide_top_info'))	{	// hide top?
		return;
	}

	if (aspen_is_checked_page_opt('pp_hide_infotop')
		&& !aspen_t_get('showposts')) {
	return;
	}

	$po = "\t\t\t<div " . aspen_meta_icons_class() . ">\n\t\t\t";

	$po .= sprintf( __( '<span class="sep posted-on">Posted on </span><a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s">%4$s</time></a><span class="by-author"> <span class="sep"> by </span> <span class="author vcard"><a class="url fn n" href="%5$s" title="%6$s" rel="author">%7$s</a></span></span>','aspen'),
		esc_url( get_permalink() ),
		esc_attr( get_the_time() ),
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		sprintf( esc_attr(__( 'View all posts by %s','aspen')), get_the_author() ),
		esc_html( get_the_author() )
	);

	if ( (aspen_getopt('show_post_avatar')
			|| aspen_is_checked_post_opt('pp_show_post_avatar')
			|| aspen_t_get('show_avatar'))
		  && aspen_getopt('show_tiny_avatar')) {
			$po .= '<span class="post-avatar-tiny">';
			$po .= get_avatar( get_the_author_meta('user_email') ,22,null,'avatar' );
			$po .= '</span>';
	}
	$po .= "\n\t\t\t</div><!-- .entry-meta-icons -->";
	echo apply_filters('aspen_posted_on',$po, $type);
}
}

if (! function_exists('aspen_format_posted_on_footer')) {
function aspen_format_posted_on_footer($who) {
	if (aspen_is_checked_post_opt('pp_hide_bottom_post_meta') || aspen_is_checked_page_opt('pp_hide_infobot')) {
		aspen_edit_link();
		return;
	}
?>
		<footer class="entry-utility">
<?php 		aspen_posted_on();
		if ( comments_open() ) {
			echo '<span ' . aspen_meta_icons_class() . '><span class="comments-link">';
			comments_popup_link( '<span class="leave-reply">' . '&nbsp;&nbsp;' . __( 'Leave a reply','aspen') . '</span>', __( '<b>1</b> Reply','aspen'),
				__( '<b>%</b> Replies','aspen') ); ?></span></span>

<?php
		}
		aspen_edit_link();
?>
		</footer><!-- #entry-utility -->
<?php
}
}

if ( ! function_exists('aspen_meta_icons_class')) {
function aspen_meta_icons_class() {
	// 'post_hide_date', 'post_hide_author', 'post_hide_cats', 'hide_singleton_cat', 'post_hide_tags'
	$class = 'meta-info-wrap';
	if (aspen_getopt('post_hide_date')) {		// check for hide various elements
		if ($class != '') $class .= ' ';
		$class .= 'post_hide_date';
	}
	if (aspen_getopt('post_hide_author')) {		// check for hide various elements
		if ($class != '') $class .= ' ';
		$class .= 'post_hide_author';
	}
	if (aspen_getopt('post_hide_cats')) {		// check for hide various elements
		if ($class != '') $class .= ' ';
		$class .= 'post_hide_cats';
	}
	if (aspen_getopt('hide_singleton_cat')) {	    // check for hide various elements
		if ($class != '') $class .= ' ';
		$class .= 'post_hide_single_cat';
	}
	if (aspen_getopt('post_hide_tags')) {		// check for hide various elements
		if ($class != '') $class .= ' ';
		$class .= 'post_hide_tags';
	}
	if (aspen_getopt('hide_permalink')) {		// check for hide various elements
		if ($class != '') $class .= ' ';
		$class .= 'post_hide_permalink';
	}
	if (aspen_getopt('post_icons')) {
		if ($class != '') $class .= ' ';
		$class .= 'entry-meta-icons';
	}
	if ($class != '') {
		return 'class="' . $class . '"';
	}
	return '';
}
}

if ( ! function_exists( 'aspen_posted_in' ) ) {
/**
 * Prints HTML with meta information for the current post-date/time and author.
 * Create your own aspen_posted_on to override in a child theme
 *
 * @since Aspen 1.0
 */
function aspen_posted_in($type='') {

	if (aspen_getopt_checked('post_info_hide_bottom')
		|| aspen_is_checked_post_opt('pp_hide_bottom_post_meta')
	|| aspen_is_checked_page_opt('pp_hide_infobot')
		|| aspen_t_get('hide_bottom_info')) {	// hide bottom?
		aspen_edit_link();
		return;
	}

	if (aspen_is_checked_page_opt('pp_hide_infobot')
		&& !aspen_t_get('showposts'))
		return;

	$pi = '<div ' . aspen_meta_icons_class() . ">\n";

	if ($type == 'single') {
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( __( ', ','aspen') );

		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', __( ', ','aspen') );
		if ( '' != $tags_list ) {
			$utility_text = __( 'This entry was posted in %1$s and tagged %2$s by <a href="%6$s">%5$s</a>. Bookmark the <a href="%3$s" title="Permalink to %4$s" rel="bookmark">permalink</a>.','aspen');
		} elseif ( '' != $categories_list ) {
			$utility_text = __( 'This entry was posted in %1$s by <a href="%6$s">%5$s</a>. Bookmark the <a href="%3$s" title="Permalink to %4$s" rel="bookmark">permalink</a>.','aspen');
		} else {
			$utility_text = __( 'This entry was posted by <a href="%6$s">%5$s</a>. Bookmark the <a href="%3$s" title="Permalink to %4$s" rel="bookmark">permalink</a>.','aspen');
		}

		if (aspen_meta_icons_class() == '') {	// not showing icons
			$pi .= sprintf(
				$utility_text,
				$categories_list,
				$tags_list,
				esc_url( get_permalink() ),
				the_title_attribute( 'echo=0' ),
				get_the_author(),
				esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) )
			);
		} else {
			if ( $categories_list ) {
				$cat_count = count( get_the_category() );
				if ($cat_count < 2 && aspen_getopt_checked('hide_singleton_cat'))
					$pi .= "\t\t\t<span class=\"cat-links post_hide_singleton_cat\">\n";
				else
					$pi .="\t\t\t<span class=\"cat-links\">\n";
				$pi .= sprintf( __( '<span class="%1$s">Posted in</span> %2$s','aspen'), 'entry-utility-prep entry-utility-prep-cat-links', $categories_list );

				$pi .="\t\t\t</span>\n";

			} // End if categories
		/* translators: used between list items, there is a space after the comma */

			if ($tags_list ) {
				$pi .="\t\t\t<span class=\"tag-links\">\n";
				$pi .= sprintf( __( '<span class="%1$s">Tagged</span> %2$s','aspen'), 'entry-utility-prep entry-utility-prep-tag-links', $tags_list );
				$pi .= "\t\t\t</span>\n";
			} // End if $tags_list

			$pi .= '<span class="permalink-icon"><a href="' .  esc_url( get_permalink()) . '" title="Permalink to ' . the_title_attribute(array('echo'=>false)) .
					'" rel="bookmark">' .  __('permalink','aspen') . '</a></span>';
		} // end not showing icons

		$pi .= aspen_edit_link('noecho');

	} else if ($type == 'reply') {
		$dummy = true;
	} else {	// else not single
		$show_sep = false;
		if ( 'page' != get_post_type() ) { // Hide category and tag text for pages on Search

			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( __( ', ','aspen') );
			$cat_count = count( get_the_category() );
			$skip =  ($cat_count < 2 && aspen_getopt_checked('hide_singleton_cat'));
			if ( $categories_list && !$skip) {
				$pi .= '<span class="cat-links">';
				$pi .= sprintf( __( '<span class="%1$s">Posted in</span> %2$s','aspen'), 'entry-utility-prep entry-utility-prep-cat-links', $categories_list );
				$show_sep = true;
				$pi .= '</span>';
			} // End if categories
			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', __( ', ','aspen') );
			if ( $tags_list ) {
				if ( $show_sep ) {
					$pi .= '<span class="sep"> | </span>';
				} // End if $show_sep
				$pi .= '<span class="tag-links">';
				$pi .= sprintf( __( '<span class="%1$s">Tagged</span> %2$s','aspen'), 'entry-utility-prep entry-utility-prep-tag-links', $tags_list );
				$show_sep = true;
				$pi .= '</span>';
			} // End if $tags_list
		} // End if 'page' != get_post_type()

		if ( comments_open() ) {
			if ( $show_sep ) {
				$pi .= '<span class="sep"> | </span>';
			} // End if $show_sep
			$pi .= '<span class="comments-link">';
			ob_start();     // yuck - why doesn't WP make all the utilities have an echo option??
			comments_popup_link( '<span class="leave-reply">' . __( 'Leave a reply','aspen') . '</span>', __( '<b>1</b> Reply','aspen'),
				 __( '<b>%</b> Replies','aspen') );
			$pi .= ob_get_clean();
			$pi .= '</span>';

		} // End if comments_open()
		$pi .= aspen_edit_link('noecho');
	}	// end non-single
	$pi .= "</div><!-- .entry-meta-icons -->\n";
	echo apply_filters('aspen_posted_in',$pi,$type);
}
}

if ( ! function_exists( 'aspen_post_top_info' ) ) {
/**
 * Prints HTML with meta information for the top meta line.
 *
 * @since Aspen 1.0
 */
function aspen_post_top_info($type='') {
	// $type for single
	aspen_posted_on($type);
}
}

if ( ! function_exists( 'aspen_post_bottom_info' ) ) {
/**
 * Prints HTML with meta information for the bottom meta line.
 *
 * @since Aspen 1.0
 */
function aspen_post_bottom_info($type='') {
	aspen_posted_in($type);
}
}

if ( ! function_exists( 'aspen_comments_popup_link' ) ) {
function aspen_comments_popup_link() {
	/* display comment bubble for posts */
	if ( !aspen_getopt_checked('pp_hide_post_bubble') && !aspen_is_checked_post_opt('pp_hide_post_bubble')
	&& comments_open() && ! post_password_required() ) { ?>
			<div class="comments-link comments-bubble">
<?php 			comments_popup_link( '<span class="leave-reply">' . __( 'Reply','aspen') .
			'</span>', _x( '1', 'comments number','aspen'), _x( '%', 'comments number','aspen') ); ?>
			</div>
<?php
	}
}
}

/**
 * Add classes to body depending of page type to make sidebar templates work.
 *
 * So, we will have blog, page, alt-left, alt-right, archive, attachement, page-posts
 *
 * @since Aspen 1.0
 */
function aspen_body_classes( $classes ) {

	$pwp = in_array('page-template-paget-posts-php',$classes);

	if ( $pwp )                 // page with posts - add stuff like blog
		$classes[] = 'blog';

	if ( ! is_multi_author() )
		$classes[] = 'single-author';

	if ( is_singular() && ! is_home() && !$pwp )    // don't make pwp singular
		$classes[] = 'singular';

	if (!is_user_logged_in())
		$classes[] = 'not-logged-in';

	$classes[] = 'aspen-theme-body';

	$classes[] = aspen_getopt('_mode_mobile');	// aspen-mobile-xxx

	if (aspen_getopt_checked('theme_width_fixed'))
		$classes[] = 'aspen-fixed-width';

	if (aspen_get_per_page_value('bodyclass') != '')	// add body class per page
		$classes[] = aspen_get_per_page_value('bodyclass');

	return $classes;
}
add_filter( 'body_class', 'aspen_body_classes' );

// ========================= tinyMCE =================================
/* route tinyMCE to our stylesheet */
function aspen_mce_css($default_style) {
	/* replace the default editor-style.css with custom CSS generated on the fly by the php version */
	if (aspen_getopt('_hide_editor_style'))
		return $default_style;

	$mce_css_file = trailingslashit(get_template_directory()) . 'editor-style-css.php';
	$mce_css_dir = trailingslashit(get_template_directory_uri()) . 'editor-style-css.php';
	if (!@file_exists($mce_css_file)) {	// see if it is there
		return $default_style;
	}
	/* do we need to do anything about rtl? */

	/* if we have a custom style file, return that instead of the default */
	// Build the overrides
	$put = '?mce=1';	// cheap way to start with ?

	if (($val = aspen_getopt('theme_width_int'))) {
	/*  figure out a good width - we will please most of the users, most of the time
		We're going to assume that mostly people will use the default layout -
		we can't actually tell if the editor will be for a page or a post at this point.
		And let's just assume the default sidebar widths.
	*/
		$default = aspen_getopt('layout_default');
		$twidth = 650;
		switch ($default) {
			case 'right-2-col':
			case 'right-2-col-bottom':
			case 'left-2-col':
			case 'left-2-col-bottom':
				$twidth = 580;
				break;		// no left sidebar for these layouts

			case 'split':
				$twidth = 580;
				break;

			case 'one-column':
				$twidth = 870;
				break;

			case 'right-1-col':
			case 'left-1-col':
			default:
				$twidth = 650;
				break;
		}

		if ($val != 940) {	// they've changed the width
			$twidth = $twidth + (int)(($val-940)*.67); // .67 by trial and error
		}
		if ($twidth != 650) {
			$put .= '&twidth=' . urlencode($twidth);
		}
	}

	if (($val = aspen_getopt('site_fontsize_int')))	// base font size
		$put .= '&fontsize=' . urlencode($val);

	if (($val = aspen_getopt('content_font')) != '') {	// content_font
		$put .= '&fontfamily=' . urlencode($val);
	}

	if (($val = aspen_getopt('title_font')) != '') {	// title font - just in tables
		$put .= '&titlefont=' . urlencode($val);
	}

	/* need to handle bg color of content area - need to do the cascade ourself */
	if (($val = aspen_getopt('editor_bgcolor')) && strcasecmp($val,'transparent') != 0) {	/* alt bg color */
		$put .= '&bg=' . urlencode($val);
	} else if (($val = aspen_getopt('content_bgcolor')) && strcasecmp($val,'transparent') != 0) {	/* #content */
		$put .= '&bg=' . urlencode($val);
	} else if (($val = aspen_getopt('container_bgcolor')) && strcasecmp($val,'transparent') != 0) {	/* #container */
		$put .= '&bg=' . urlencode($val);
	} else if (($val = aspen_getopt('main_bgcolor')) && strcasecmp($val,'transparent') != 0) { /* #main */
		$put .= '&bg=' . urlencode($val);
	} else if (($val = aspen_getopt('page_bgcolor')) && strcasecmp($val,'transparent') != 0) { /* #wrapper */
		$put .= '&bg=' . urlencode($val);
	} else if (($name = aspen_getopt('themename')) && strcasecmp($name,'Transparent Dark') === 0) {
		$put .= '&bg=' . urlencode('#222');
	} else if (($name = aspen_getopt('themename')) && strcasecmp($name,'Transparent Light') === 0) {
		$put .= '&bg=' . urlencode('#ccc');
	}

	if (($val = aspen_getopt('content_color')) ) {	// text color
		$put .= '&textcolor=' . urlencode($val);
	}

	if (($val = aspen_getopt('content_headings_color')) ) {	// headings color
		$put .= '&hdgcolor=' . urlencode($val);
	}

	if (($val = aspen_getopt('input_bgcolor')) ) {	// input area
		$put .= '&inbg=' . urlencode($val);
	}
	if (($val = aspen_getopt('input_color')) ) {
		$put .= '&incolor=' . urlencode($val);
	}

	if (($val = aspen_getopt('link_color')) ) {	// link
		$put .= '&a=' . urlencode($val);
	}
	if (($val = aspen_getopt('link_hover_color')) ) {
		$put .= '&ahover=' . urlencode($val);
	}

	if (($val = aspen_getopt('aspen_tables')) ) {	// table type
		$put .= '&table=' . urlencode($val);
	}

	if (($val = aspen_getopt('contentlist_bullet')) ) {	// list bullet
		$put .= '&list=' . urlencode($val);
	}

	// images
	if (($val = aspen_getopt('caption_color')) ) {	// image caption, border color, width
		$put .= '&imgcapt=' . urlencode($val);
	}
	if (($val = aspen_getopt('media_lib_border_color')) ) {
		$put .= '&imgbcolor=' . urlencode($val);
	}
	if (($val = aspen_getopt('media_lib_border_int')) ) {
		$put .= '&imgbwide=' . urlencode($val);
	}

	return $default_style . ',' . $mce_css_dir . $put;
}

add_filter('mce_css','aspen_mce_css');

// ========================= special content =========================
if ( ! function_exists('aspen_the_page_contnt_featured')) {
function aspen_the_page_contnt_featured($include_content=true) {

	if ( !aspen_getopt('hide_page_featured') ) {
		aspen_use_fi_in_content('page');
	}
	if (!$include_content) {
		return;
	}
	aspen_the_contnt();
}
}

if ( ! function_exists('aspen_the_contnt_featured')) {
function aspen_the_contnt_featured() {

	if ( aspen_getopt('show_featured_image_fullposts')
			|| (aspen_getopt('always_excerpt') && aspen_getopt('show_featured_image_excerptedposts'))
			|| aspen_is_checked_post_opt('pp_show_featured') ) {
		aspen_use_fi_in_content();
	}
	if (aspen_is_checked_page_opt('pp_show_featured_img'))
		aspen_use_fi_in_content();

	global $more;
	$more = false;		// need this to make it act like regular blog page
	$m = aspen_continue_reading_link(false);
	aspen_the_contnt($m);
}
}

if ( ! function_exists('aspen_the_contnt_featured_single')) {
function aspen_the_contnt_featured_single() {
	if  (aspen_getopt('show_featured_image_fullposts')
			|| aspen_is_checked_post_opt('pp_show_featured') ) {
		aspen_use_fi_in_content('single');
	}
	if (aspen_is_checked_page_opt('pp_show_featured_img'))
	aspen_use_fi_in_content('single');
	aspen_the_contnt();
}
}

if ( ! function_exists('aspen_the_excerpt_featured')) {
function aspen_the_excerpt_featured($always_excerpt=false) {
	if ( (aspen_getopt('show_featured_image_excerptedposts')
		|| aspen_is_checked_post_opt('pp_show_featured')
		|| aspen_t_get('show_featured_image'))
		&& !aspen_t_get('hide_featured_image')) {
		aspen_use_fi_in_content();
	}
	if (aspen_is_checked_page_opt('pp_show_featured_img'))
		aspen_use_fi_in_content();
	the_excerpt('more...');
}
}

if ( ! function_exists('aspen_the_contnt')) {
function aspen_the_contnt($m='') {
	if ((aspen_is_checked_page_opt('pp_raw_html') && !aspen_t_get('showposts')) || aspen_is_checked_post_opt('pp_raw_html')) {
		remove_filter ('the_content', 'wpautop');
        remove_filter ('the_content', 'wptexturize');
	}
	the_content($m);

}
}

if ( ! function_exists('aspen_show_only_title')) {
function aspen_show_only_title() {
	if ( (! aspen_t_get( 'showposts' )
          &&  ( aspen_get_per_page_value('wvr_pwp_type') == 'title'
                || aspen_get_per_page_value('wvr_pwp_type') == 'title_featured'
              )
         )
		|| aspen_t_get('show') == 'title'
		|| aspen_t_get('show') == 'title_featured'
	   ) {
		echo "\t</article><!-- #post -->\n";
		return true;
	}
	return false;
}
}

if ( ! function_exists('aspen_use_fi_in_content')) {
function aspen_use_fi_in_content($page_type = 'post') {
	global $aspen_header;
	$default = 'thumbnail';
	$width = '';

	if (get_post_thumbnail_id()) {
		$image = wp_get_attachment_image_src( get_post_thumbnail_id( ), 'full' );        // (url, width, height)
		$href = $image[0];

		if ($image[1] < $aspen_header['width'] || aspen_getopt('hide_featured_header')) {

			switch ($page_type) {
				case 'page':
					$default = 'medium';   // medium is default for pages
					$width = aspen_getopt('featured_page_width');
					$size = aspen_getopt('fi_size_page');
					break;

				case 'single':
					$default = 'medium';   // medium is default for single posts
					$width = aspen_getopt('featured_single_width');
					$size = aspen_getopt('fi_size_post_single');
					break;

				default:        // excerpts
					$width = aspen_getopt('featured_blog_width');
					$size = aspen_getopt('fi_size_post');
					$href = get_permalink();
					 break;
			}

			if ($width != '0') {        // don't emit any FI if the width is explicit set to 0
				if (empty($size)) $size = $default;
?>
				<span class='featured-image'><a href="<?php echo $href; ?>"><?php esc_url(the_post_thumbnail( $size )); ?></a></span>
<?php
			return true;
			}
		}
	}
	return false;
}
}

if ( ! function_exists('aspen_do_excerpt')) {
function aspen_do_excerpt() {
	// return true if this kind of page should be excerpted

	if (aspen_t_get('show')=='excerpt')   // for Aspen Pro
		return true;

	if (aspen_t_get('show')=='full')   // for Aspen Pro
		return false;

	if (aspen_is_checked_post_opt('pp_force_post_excerpt'))
		return true;

	if (aspen_is_checked_post_opt('pp_force_post_full'))
		return false;

	$n1 = aspen_get_per_page_value('pp_fullposts');
	if (!$n1)
		$n1 = aspen_getopt('fullpost_first');

	if ($n1) {
		global $page, $paged;
		if (!( $paged >= 2 || $page >= 2 )
		 && aspen_post_count() <= $n1)
			return false;
	}

	$pwp = aspen_get_per_page_value('wvr_pwp_type');

	if ($pwp == 'full')	// need to check before archive/search
		return false;	// override global setting
	if ($pwp == 'excerpt')
		return true;	// override global setting

	if (is_search()) {
		return !aspen_getopt_checked('fullpost_search');
	}
	if (is_archive()) {
		return !aspen_getopt_checked('fullpost_archive');
	}

	return aspen_getopt_checked('excerpt_blog');
}
}

if ( ! function_exists('aspen_page_menu')) {
	function aspen_page_menu() {
	/* handle sf-menu for wp_page_menu */
	$menu = wp_page_menu(array('echo' => false));
	if ( aspen_use_sf() ) {
		$ulpos = stripos($menu, '<ul>');
		if ($ulpos !== false) {
			echo substr_replace($menu, '<ul class="sf-menu">',$ulpos, 4);
		}
	} else {
		echo $menu;
	}
}
}

// ========================= sidebars ================================

if ( ! function_exists( 'aspen_get_sidebar_left' ) ) {
function aspen_get_sidebar_left($who) {

	$layout = aspen_get_page_layout($who);

	switch ($layout) {
		case 'right-1-col':
		case 'right-2-col':
		case 'right-2-col-bottom':
			break;		// no left sidebar for these layouts

		case 'split':
			get_sidebar('left-split');
			break;

		case 'left-1-col':
		case 'left-2-col':
		case 'left-2-col-bottom':
			get_sidebar($layout);
			break;

		default:
			break;
	}
}
} // end function exists

if ( ! function_exists( 'aspen_get_sidebar_right' ) ) {
function aspen_get_sidebar_right($who) {

	$layout = aspen_get_page_layout($who);

	switch ($layout) {
		case 'right-1-col':
		case 'right-2-col':
		case 'right-2-col-bottom':
			get_sidebar($layout);
			break;

		case 'split':
			get_sidebar('right-split');
			break;

		case 'left-1-col':
		case 'left-2-col':
		case 'left-2-col-bottom':
			break;		// no right sidebar for these layouts

		default:
			break;
	}
}
} // end function exists

if ( ! function_exists( 'aspen_get_sidebar_top' ) ) {
function aspen_get_sidebar_top($who) {
	if (!aspen_is_checked_page_opt('sitewide-top-widget-area'))
		aspen_put_widgetarea('sitewide-top-widget-area','sidebar_top');	// sitewide top

	if (!aspen_is_checked_page_opt('top-widget-area')) {
		switch ($who) {
			case 'index':
			case 'pwp':
			case 'single':
				aspen_put_widgetarea('blog-top-widget-area','sidebar_top');
				break;

			case 'page':
				aspen_put_widgetarea('top-widget-area','sidebar_top');
				break;

			case '404':
			case 'archive':
			case 'author':
			case 'category':
			case 'search':
			case 'tag':
				aspen_put_widgetarea('postpages-widget-area','sidebar_top');
				break;

			case 'image':
			default:
				break;
		}
	} // end not per page hide
}
} // end function exists

if ( ! function_exists( 'aspen_get_sidebar_bottom' ) ) {
function aspen_get_sidebar_bottom($who) {

	if (!aspen_is_checked_page_opt('bottom-widget-area')) {
		switch ($who) {
			case 'index':
			case 'pwp':
			case 'single':
				aspen_put_widgetarea('blog-bottom-widget-area','sidebar_bottom');
				break;

			case 'page':
				aspen_put_widgetarea('bottom-widget-area','sidebar_bottom');
				break;

			case 'archive':
			case 'author':
			case 'category':
			case 'tag':
			case 'search':
			case '404':
				break;

			case 'image':

			default:
				break;
		}
	} // end not hide bottom per page

	if (!aspen_is_checked_page_opt('sitewide-bottom-widget-area'))
		aspen_put_widgetarea('sitewide-bottom-widget-area','sidebar_bottom');		// sitewide bottom
}
} // end function exists

if ( ! function_exists( 'aspen_get_page_layout' ) ) {
function aspen_get_page_layout($who) {
	// determine the layout structure of a page from the settings.
	// blogs, pages, and single will use the 'right-1-col' as a default
	// others will be 'none' - no sidebars - by default
	// each page can be set to its own default. Individual pages
	// can be set to a layout on a per-page basis.

	$default = aspen_getopt('layout_default');
	if (!$default) $default = 'right-1-col';	// use something!
		$arc_default = aspen_getopt('layout_default_archive');
	if (!$arc_default) $arc_default = 'one-column';	// use something!

	$per_page = aspen_get_per_page_value('pp_page_layout');
	if ($per_page != '')
		return $per_page;

	switch ($who) {
		case 'index':
		case 'pwp':
			$l = aspen_getopt('layout_blog');
			return (!$l || $l == 'default') ? $default : $l;

		case 'single':
			if (aspen_is_checked_post_opt('pp_hide_sidebars'))
				return 'one-column';
			$l = aspen_getopt('layout_single');
			return (!$l || $l == 'default') ? $default : $l;

		case 'page':
			$l = aspen_getopt('layout_page');
			return (!$l || $l == 'default') ? $default : $l;

		case 'archive':
			$l = aspen_getopt('layout_archive');
			return (!$l || $l == 'default') ? $arc_default : $l;

		case 'author':
			$l = aspen_getopt('layout_author');
			return (!$l || $l == 'default') ? $arc_default : $l;

		case 'category':
			$l = aspen_getopt('layout_category');
			return (!$l || $l == 'default') ? $arc_default : $l;

		case 'tag':
			$l = aspen_getopt('layout_tag');
			return (!$l || $l == 'default') ? $arc_default : $l;

		case 'search':
		case '404':
			$l = aspen_getopt('layout_search');
			return (!$l || $l == 'default') ? $arc_default : $l;

		case 'image':
			$l = aspen_getopt('layout_image');
			return (!$l || $l == 'default') ? $arc_default : $l;

		default:
			return $default;
	}

	return $default;
}
} // end function exists

if ( ! function_exists( 'aspen_get_page_class' ) ) {
function aspen_get_page_class($who, $extra = '', $noecho = false) {

	$class = $extra;
	if ($class != '') $class .= ' equal_height';
	else $class = 'equal_height';
	$layout = aspen_get_page_layout($who);
	if ($class == '')
		$class = $layout;
	else
		$class .= ' ' . $layout;

	if ($class != '')
		$class = ' class="' . $class . '"';
	if (!$noecho ) echo ($class);
	return $class;
}
} // end function exists

if ( ! function_exists('aspen_show_primary_sidebar')) {
function aspen_show_primary_sidebar() {
	// WordPress widget code is screwed up. If NO widget areas are defined, then it is possible
	// for primary-widget-area to not be active. If the other two are active, then the is_active_sidebar
	// for primary will be true, also, even if it has no widgets. Thus we use the ob stuff.
	// If no areas are defined, then the is_active fails, and we end up at the default message.

	$primary = apply_filters('aspen_replace_widget_area','primary-widget-area');

	if ( !aspen_is_checked_page_opt('primary-widget-area') ) {

		if ( is_active_sidebar( $primary ) ) {
			ob_start();	// make sure not empty
			$success = dynamic_sidebar( $primary );
			$content = ob_get_clean();
			if ($success) {
?>
		<div id="<?php echo $primary;?>" class="widget-area aspen-clear" role="complementary">
<?php	        echo $content;
?>
		</div><!-- #primary-widget-area .widget-area -->
<?php 	    }
		} else if ( !is_active_sidebar( apply_filters('aspen_replace_widget_area','right-widget-area' )) && !is_active_sidebar( $primary )
				&& !is_active_sidebar( apply_filters('aspen_replace_widget_area','left-widget-area' ))) {	// no active primary or right
?>
	<div id="<?php echo $primary;?>" class="widget-area aspen-clear" role="complementary">
			<aside id="sidebar_primary_default" class="widget">
		<h3 class="widget-title"><?php echo( 'Primary Sidebar Area' /*a*/ ); ?></h3>
		<ul><li>
<strong>Add Some Widgets!</strong><br />This theme has been designed to be used with sidebars. <span style="color:red">This message will no longer be displayed after you add at least one widget to one of the Sidebar Widget Areas using the Appearance &rarr; Widgets control panel.</span></li>
<li>
<?php       wp_loginout(); ?>
</li>
		</ul>
		</aside>
	</div>
<?php
		} // no active primary or right
	}
}
}

if ( ! function_exists('aspen_put_widgetarea')) {
function aspen_put_widgetarea($area_name, $style ) {
	// emit ttw widget area depending on various settings (for page.php and index.php)

	$area = apply_filters('aspen_replace_widget_area',$area_name);

	if (aspen_is_checked_page_opt($area)) return;		// hide area option checked

	if (is_active_sidebar($area)) { /* add top and bottom widget areas */
		ob_start(); /* let's use output buffering to allow use of Dynamic Widgets plugin and not have empty sidebar */
		$success = dynamic_sidebar($area);
		$content = ob_get_clean();
		if ($success) {
?>
	<div id="<?php echo $area; ?>" class="widget-area <?php echo $style; ?>" role="complementary">
<?php	    echo($content) ; ?>
	</div><!-- <?php echo $area; ?> -->
<?php
		}
	}
}
}

//============================ Header and Footer ===================================

if ( ! function_exists( 'aspen_get_header' ) ) {
function aspen_get_header($who) {
	global $aspen_header_who;
	$aspen_header_who = $who;
	get_header($who);
}
} // end function exists

if ( ! function_exists( 'aspen_get_footer' ) ) {
function aspen_get_footer($who) {
	echo "    <div class='aspen-clear'></div></div><!-- #main -->\n";
	get_footer($who);
}
} // end function exists

// ================================ Aspen admin ================================

function aspen_wp_head() {	// action definition
	require_once('includes/wphead.php');
	aspen_generate_wphead();
}

function aspen_unlink_page($link, $id) {	// filter definition
	$stay = get_post_meta($id, 'pp_stay_on_page', true);
	if ($stay) {
		return "#";
	} else {
		return $link;
	}
}

function aspen_get_css_filename() {
	$updir = wp_upload_dir();
	return trailingslashit($updir['basedir']) . 'aspen-subthemes/style-aspen.css';
}

function aspen_get_css_url() {
	$updir = wp_upload_dir();
	// make relative for https: - doesn't work right...
	// return parse_url(trailingslashit($updir['baseurl']) . 'aspen-subthemes/style-aspen.css',PHP_URL_PATH);
	$path = trailingslashit($updir['baseurl']) . 'aspen-subthemes/style-aspen.css';
	if (is_ssl()) $path = str_replace('http:','https:',$path);
	return $path;
}

function aspen_add_admin() {	// action definition
	/* adds our admin panel  (add_action: admin_menu) */
	// 'edit_theme_options' works for both single and multisite
	$page = add_theme_page('Aspen', '<span style="color:orange;">&spades;</span>' . ASPEN_THEMENAME . ' ' . aspen_t_('Admin' /*a*/ ), 'edit_theme_options', 'Aspen', 'aspen_admin');
	/* using registered $page handle to hook stylesheet loading for this admin page */
	add_action('admin_print_styles-'.$page, 'aspen_admin_scripts');
}

function aspen_admin() {
	$wp_vers = $GLOBALS['wp_version'];
	$cur_vers = $wp_vers;
	$beta = strpos($cur_vers, '-');
	if ( $beta > 0 ) {
		$cur_vers = substr($cur_vers,0,$beta);	// strip the beta part if there
	}
	if (version_compare($cur_vers, ASPEN_MIN_WPVERSION, '<')) {
		echo '<br><br><h2 style="padding:4px;background:pink;">ERROR: You are using WordPress Version ' . $GLOBALS['wp_version'] . '. Aspen requires <em>WordPress Version ' . ASPEN_MIN_WPVERSION . '</em> or above. You should always upgrade to the latest version of WordPress for maximum site performance and security.</h2>';	// admin message
		return;
	}

	require_once(dirname( __FILE__ ) . '/includes/admin-top.php'); // NOW - load the admin stuff
	do_action('aspen_pro_add_admin');
	aspen_do_admin();
}

function aspen_admin_scripts() {
	/* called only on the admin page, enqueue our special style sheet here (for tabbed pages) */
	wp_enqueue_style('wiiStylesheet', get_template_directory_uri().'/admin-style.css');

	wp_enqueue_style ("thickbox");
	wp_enqueue_script ("thickbox");

	wp_enqueue_script('wiiJscolor', get_template_directory_uri().'/js/jscolor/jscolor.js',ASPEN_VERSION);
	wp_enqueue_script('wiiYetii', get_template_directory_uri().'/js/yetii/yetii'.ASPEN_MINIFY.'.js',ASPEN_VERSION);
	wp_enqueue_script('wiiHide', get_template_directory_uri().'/js/theme/hide-css'.ASPEN_MINIFY.'.js',ASPEN_VERSION);
	wp_enqueue_script('wiiMediaLib', get_template_directory_uri().'/js/theme/media-lib'.ASPEN_MINIFY.'.js',ASPEN_VERSION);
}

function aspen_admin_head() {	// action definition
}

function aspen_enqueue_scripts() {	// action definition

	// need to know the page template for some conditional script inclusion
	global $aspen_cur_template;

	$aspen_cur_template = (is_page()) ? get_page_template() : 'nonpage';

	$vers = aspen_getopt('style_version');
	if (!$vers) $vers = '1';
	else $vers = sprintf("%d",$vers);

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	// emit Aspen js vars - must be here, before scripts
			// generate JS values for Aspen JS Lib
	echo '<script type="text/javascript">';
	echo 'var aspenIsStacked=' . ((strpos( aspen_getopt('_mode_mobile'), 'nostack' ) === false) ? 'true;' : 'false;');
	$tw = aspen_getopt('theme_width_int');
	if (!$tw) $tw = 940;
	echo 'var aspenThemeWidth=' . $tw . ';';
	$threshold = aspen_getopt('mobile_slide_threshold');	// default threshold
	if (aspen_getopt_checked('theme_width_fixed')) {		// no menu swap if fixed width theme
		$threshold = 1;
	} else {
		$threshold = $threshold != '' ? $threshold : '640';
	}
	echo 'var aspenMenuThreshold=' . $threshold . ';';
	echo 'var aspenHideMenuBar=' . (aspen_getopt('hide_menu_bar') ? 'true;' : 'false;');
	echo 'var aspenUseSuperfish=' . (aspen_getopt('use_superfish') ? 'true;' : 'false;');
	echo "</script>\n";

	//-- Aspen js lib - requires jQuery...

	wp_enqueue_script('aspenJSLib', get_template_directory_uri().'/js/aspenjslib'.ASPEN_MINIFY.'.js',array('jquery'),ASPEN_VERSION,true);

	// dynamic settings for menu fixer
	$default_selector = 'li:has(ul) > a';
	$default_selector_leaf = 'li li li:not(:has(ul)) > a';
	$params = array(
	'selector' => apply_filters('aspen_menu_selector', $default_selector),
	'selector_leaf' => apply_filters('aspen_menu_selector_leaf', $default_selector_leaf)
	);
	wp_localize_script('aspenJSLib', 'aspen_menu_params', $params);


	global $aspen_cur_page_ID;
	global $post;

	if (!$aspen_cur_page_ID && is_object($post))
        $aspen_cur_page_ID = get_the_ID();

	aspen_masonry('enqueue-script');
}

function aspen_wp_title($title) {	// filter definition

	if (function_exists('wpseo_get_value'))
		return $title;		// this is compatible with SEO plugins

	/*
	 * Print the <title> tag based on what is being viewed. THIS CODE DIRECTLY FROM TWENTY ELEVEN
	 */
	global $page, $paged;

	$t = '';

	if ($title) {
		$title = trim(str_replace('&raquo;','',$title));
		$t = $title . ' | ';
	}

	$t .= get_bloginfo('name');

	/* Add the blog description for the home/front page. */
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		$t .= " | $site_description";

	/* Add a page number if necessary: */
	if ( $paged >= 2 || $page >= 2 )
		$t .= ' | ' . sprintf( __( 'Page %s','aspen'), max( $paged, $page ) );

	return $t;
}


if ( ! function_exists('aspen_not_found_search')) {
function aspen_not_found_search($file_name) {
?>
	<article id="post-0" class="post no-results not-found">
	<header class="entry-header">
		<h1 class="entry-title"><?php echo __( 'Nothing Found','aspen'); ?></h1>
	</header><!-- .entry-header -->

	<div class="entry-content cf">
		<p>
<?php
		if (!aspen_getopt('_hide_not_found_search')) {
		echo __( 'Apologies, but no results were found for the requested archive. Perhaps searching will help find a related post.','aspen');
?>
		</p>
			<p>
<?php
			get_search_form();
		}
?>
		</p>
	</div><!-- .entry-content -->
	</article><!-- #post-0 -->
<?php
}
}

// Change what's hidden by default - show Custom Fields and Discussion by default!

function aspen_hidden_meta_boxes($hidden, $screen) {	// filter definition
	if ( 'post' == $screen->base || 'page' == $screen->base )
		$hidden = array('slugdiv', 'trackbacksdiv', 'postexcerpt', 'commentsdiv', 'authordiv', 'revisionsdiv');
		// removed 'postcustom', 'commentstatusdiv',
	return $hidden;
}

function aspen_the_excerpt_filter($excerpt) {	// filter definition
	return do_shortcode($excerpt);
}

function aspen_get_wp_title_rss($title) {		// filter definition
	/* need to fix our add a | blog name to wp_title */
	$ft = str_replace(' | ','',$title);
	return str_replace(get_bloginfo('name'),'',$ft);
}

// apply_filters('get_bloginfo_rss', convert_chars($info), $show);

require_once(dirname( __FILE__ ) . '/settings.php');	// settings stay in theme root directory
require_once(dirname( __FILE__ ) . '/includes/lib-runtime.php');	// standard runtime library
require_once(dirname( __FILE__ ) . '/includes/admin-page-posts.php');	// page-posts admin

/* This is where the theme hooks into the rest of WordPress */
// ==FILTERS
add_filter('page_link', 'aspen_unlink_page', 10, 2);		// for stay on page
add_filter('wp_title', 'aspen_wp_title', 10, 1);		// filter the title
add_filter('default_hidden_meta_boxes', 'aspen_hidden_meta_boxes', 10, 2);
add_filter('the_excerpt','aspen_the_excerpt_filter', 10,1);
add_filter('get_wp_title_rss', 'aspen_get_wp_title_rss',10,1);

// ==ACTIONS
add_action('admin_init', 'aspen_admin_init_cb');
add_action('wp_head', 'aspen_wp_head');
add_action('admin_menu', 'aspen_add_admin',5);
add_action('admin_head', 'aspen_admin_head');
add_action('wp_enqueue_scripts', 'aspen_enqueue_scripts' );

/* filters available for Aspen child-themes

	add_filter('aspen_options','aspen_child_options',10,1);
	function aspen_child_options($opt_name) {
	// WP get_option (etc.) name that Aspen uses for various settings:
	// does not return the options - just the option name.
	// So one might change 'aspen_settings' to 'wvrchild_aspen_settings' (i.e., add 'wvrchild_' to the beginning)
	//
	// 'aspen_settings' - the main Aspen options
	// 'aspen_pro' - Aspen Pro options
	// 'aspen_settings_backup' - saved settings from Save/Restore
	}

===============
	Other Filters:

	'aspen_author_bio_avatar_size'
	'aspen_menu_selector'
	'aspen_menu_selector_leaf'
	'aspen_css' - process path macros in CSS code
	'aspen_attachment_size'
	'aspen_show_posts_wp_query' - to process [aspen_show_posts] WP_Query args (in shortcodes.php)
	'aspen_pwp_wp_query' - process WP_Query args from Page with Posts template (in paget-posts.php)
	'aspen_text' - text in widgets
	'aspen_switch_theme' - for switch theme plugin
	'aspen_attachment_size'
	'aspen_menu_name'
*/


// ============================== Recommended Plugins =========================
/**
 * Add plugin automation file
 */
if (current_user_can('activate_plugins')) {
require_once( dirname( __FILE__ ) . '/includes/class-tgm-plugin-activation.php' );

function aspen_install_tgm_plugins() {
	$plugins = array(

		// This is an example of how to include a plugin pre-packaged with a theme
		array(
			'name'     => 'Aspen Shortcodes and Widgets', // The plugin name
			'slug'     => 'aspen-shortcodes-and-widgets', // The plugin slug (typically the folder name)
			'required' => false
		),
				array(
			'name'     => 'Aspen Theme Extras', // The plugin name
			'slug'     => 'aspen-extras', // The plugin slug (typically the folder name)
			'required' => false
		)
	);


	// Change this to your theme text domain, used for internationalising strings
	$theme_text_domain = 'weaver-ii';

	/**
	 * Array of configuration settings. Amend each line as needed.
	 * If you want the default strings to be available under your own theme domain,
	 * leave the strings uncommented.
	 * Some of the strings are added into a sprintf, so see the comments at the
	 * end of each line for what each argument will be.
	 */

	$config = array(
		'domain'           => $theme_text_domain, // Text domain - likely want to be the same as your theme.
		'default_path'     => '', // Default absolute path to pre-packaged plugins
		'parent_menu_slug' => 'themes.php', // Default parent menu slug
		'parent_url_slug'  => 'themes.php', // Default parent URL slug
		'menu'             => 'install-weaver-ii-addons', // Menu slug
		'has_notices'      => true, // Show admin notices or not
		'is_automatic'     => true, // Automatically activate plugins after installation or not
		'message'          => '<p>The following plugins are highly recommended for full functioning of the Aspen theme. These plugins will add shortcodes that make it easy to control and add content to your site, including [aspen_show_posts], optional display of text on mobile sites, and the ability to easily add new premium subthemes for the Aspen Theme.</p>', // Message to output right before the plugins table
		'strings'          => array(
			'page_title'                      => __( 'Aspen Theme Recommended Plugins', $theme_text_domain ),
			'menu_title'                      => __( '<span style="color:orange;">&spades;</span>Aspen Plugins', $theme_text_domain ),
			'installing'                      => __( 'Installing Plugin: %s', $theme_text_domain ), // %1$s = plugin name
			'oops'                            => __( 'Something went wrong with the plugin API.', $theme_text_domain ),
			'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.' ), // %1$s = plugin name(s)
			'notice_can_install_recommended'  => _n_noop( 'Aspen Theme recommends this plugin, %1$s, to enable the complete theme feature set.', 'Aspen Theme recommends these plugins, %1$s,  to enable the complete theme feature set.' ), // %1$s = plugin name(s)
			'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.' ), // %1$s = plugin name(s)
			'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.' ), // %1$s = plugin name(s)
			'notice_can_activate_recommended' => _n_noop( 'Please activate this recommended plugin, %1$s, to enable the complete Aspen Theme feature set.', 'Please activate these recommended plugins, %1$s, to enable the complete Aspen Theme feature set.' ), // %1$s = plugin name(s)
			'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.' ), // %1$s = plugin name(s)
			'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with Aspen: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.' ), // %1$s = plugin name(s)
			'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.' ), // %1$s = plugin name(s)
			'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins' ),
			'activate_link'                   => _n_noop( 'Open Plugins Admin Page to Activate', 'Open Plugins Admin Page to Activate' ),
			'return'                          => __( 'Return to Required Plugins Installer', $theme_text_domain ),
			'plugin_activated'                => __( 'Plugin activated successfully.', $theme_text_domain ),
			'complete'                        => __( 'All plugins installed and activated successfully. %s', $theme_text_domain ) // %1$s = dashboard link
		)
	);

	tgmpa( $plugins, $config );

}

add_action( 'tgmpa_register', 'aspen_install_tgm_plugins' );
}


// ============================== MORE WEAVER THEME ACTIONS ===================
function aspen_nav_action($where) {
	get_template_part('nav',$where);
}

if (!has_action('aspen_nav'))
	add_action( 'aspen_nav', 'aspen_nav_action');

/**
 * Add theme support for infinite scroll
 *
 * @uses add_theme_support
 * @action after_setup_theme
 * @return null
 */
function aspen_infinite_scroll_init() {
	add_theme_support( 'infinite-scroll', array(
		'container' => 'content',
		'type' => 'click'
	) );
}
add_action( 'after_setup_theme', 'aspen_infinite_scroll_init' );

/*
 *	Support for Woo Commerece
 */
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10);
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10);
add_action('woocommerce_before_main_content', 'aspen_woo_wrapper_start', 10);
add_action('woocommerce_after_main_content', 'aspen_woo_wrapper_end', 10);

add_filter('widget_text', 'do_shortcode');		// add shortcode processing to standard text widget

function aspen_woo_wrapper_start() {
  echo '<div id="container" class="cf"><div id="content" class = "cf aspen-woo" role="main">';
}

function aspen_woo_wrapper_end() {
	echo '</div></div> <!-- end aspen-woo -->';
}

add_theme_support( 'woocommerce' );
/**
 * Add default options and show Options Panel after activate
 */

?>
