<?php
if ( !defined('ABSPATH')) exit; // Exit if accessed directly
/* Aspen - admin Save/Restore
 *
 * This will come after the Options form has been closed, and is used for non-SAPI options
 *
 */

function aspen_admin_saverestore() {
?>

<div class="atw-option-header" style="clear:both;">Save/Restore Theme Settings <?php aspen_help_link('help.html#SaveRestore','Help on Save/Restore Themes');?></div><br />
<div class="atw-option-subheader">Save/Restore Current Settings using WordPress Database</div>
<p>This option allows you to save and restore all current theme settings using your host's WordPress
database. Your options will be
preserved across Aspen theme upgrades, as well when you change to different themes. There is only one
saved backup avaiable. You can also download your setting to your computer with the options below.</p>
<p>Note: This save option saves <strong>all</strong> settings, including those marked with a &diams;.</p>
<form name="save_mysave_form" method="post">
	<span class="submit"><input type="submit" name="save_mytheme" value="Save Current Settings"/></span>
	<strong>Save all current settings in host WordPress database.</strong>
<?php	 aspen_nonce_field('save_mytheme'); ?>
	<br /><br />
	<span class="submit"><input type="submit" name="restore_mytheme" value="Restore Settings"/></span>
	<strong>Restore from saved settings.</strong>
<?php 	aspen_nonce_field('restore_mytheme'); ?>
	</form>

<?php

	aspen_saverestore();

	do_action('aspen_child_saverestore');	// allow additional save/restore in child */
	do_action('aspen_pro_admin','save_restore');

	do_action('aspen_child_update');
?>
	<div class="atw-option-subheader">Reset Current Settings to Default</div><br />
	<form name="resetaspen_form" method="post" onSubmit="return confirm('Are you sure you want to reset all Aspen settings?');">
		<strong>Click the Clear button to reset all Aspen settings to the default values.</strong><br >
		<em>Warning: You will lose all current settings.</em> You should use the Save/Restore tab to save a copy
		of your current settings before clearing! <br />
		<span class="submit"><input type="submit" name="reset_aspen" value="Clear All Aspen Settings"/></span>
		<?php aspen_nonce_field('reset_aspen'); ?>
	</form> <!-- resetaspen_form -->
	<br /><hr />

<?php
	$last = aspen_getopt('last_option');
	if ($last != 'Aspen') // check for case of limited PHP $_POST values
	{
?>
<p style="color:red">Possible Non-Standard Web Host Configuration detected. If your options
are not saving correctly, your host may have limited the default number of values that PHP can use for
settings. Try saving your settings again, and if this message persists, please contact your host and ask them to "Increase the PHP <em>max_input_vars</em> value for $_POST to at least 600." If that does not fix the issue,
please contact Aspen support. (diagnostic info: last_option="<?php echo $last;?>").
</p>
<?php
	} else {
	echo "<p><small>$last</small></p>";
	}
}

function aspen_process_options_admin_standard() {
	if (aspen_submitted('reset_aspen')) {
		if (! current_user_can('manage_options'))
			wp_die('You do not have the capability to do that.');
        // delete everything!
        aspen_save_msg(aspen_t_('All Aspen settings have been reset to the defaults.','aspen'));
        delete_option( apply_filters('aspen_options','aspen_settings') );
        global $aspen_opts_cache;
        $aspen_opts_cache = false;	// clear the cache
        aspen_init_opts('reset_aspen');
		update_user_meta( get_current_user_id(), 'tgmpa_dismissed_notice', 0 );     // reset the dismiss on the plugin loader
	}

	if (aspen_submitted('uploadtheme') && function_exists('aspen_loadtheme')) {
		aspen_loadtheme();
	}

	if (aspen_submitted('check_aspen')) {
        // perform Aspen check
        require_once('check-theme.php');	// include check code now
        aspen_perform_check();
	}

}

function aspen_saverestore(){
	/* admin tab for saving and restoring theme */
	$aspen_theme_dir = esc_url(aspen_f_uploads_base_dir() .'aspen-theme/');
	$download_path = esc_url(aspen_relative_url('includes/download.php'));
	$download_img_path = esc_url(aspen_relative_url('images/icons/download.png'));
	$nonce = wp_create_nonce('aspen_download');
	$a_pro = (function_exists('aspen_pro_plugin_installed')) ? '-pro' : '';

?>
<h3 class="atw-option-subheader" style="color:blue;">Save/Restore Current Theme Settings using Your Computer</h3>
<p>This option allows you to save and restore all current theme settings by uploading and downloading to your
own computer.</p>

<h3>Download Current Settings To Your Computer</h3>

<a href="<?php echo $download_path . '?_wpnonce=' . $nonce; ?>"><img src="<?php echo esc_url($download_img_path); ?>" />&nbsp; <strong>Download</strong>&nbsp;</a> - <strong><em>All</em></strong> current settings to file <strong>aspen-backup-settings<?php echo $a_pro;?>.abu</strong> on your computer. (Full settings backup, including those marked with a &diams;.)
<br />
<br />
<a href="<?php echo $download_path . '?_wpnoncet=' . $nonce;?>"><img src="<?php echo esc_url($download_img_path); ?>" />&nbsp;<strong>Download</strong></a>&nbsp; - <strong><em>Only theme related</em></strong> current settings to file <strong>aspen-theme-settings<?php echo $a_pro;?>.ath</strong> on your computer.

<?php
if (function_exists('aspen_pro_plugin_installed'))
	echo "<p>Note: Downloaded settings include <em>Aspen Pro</em> settings. Setting files from Aspen Pro can be uploaded to the Free Aspen version,
	but will not be used or saved by the free version.</p>"
?>
<form enctype="multipart/form-data" action="<?php echo $_SERVER["REQUEST_URI"]; ?>" method="POST">
	<table>
			<tr><td><h3>Upload settings from file saved on your computer</h3></td></tr>
		<tr valign="top">
			<td>Select theme/backup file to upload: <input name="uploaded" type="file" />
			<input type="hidden" name="uploadit" value="yes" />&nbsp;(Restores settings in file to current settings.)
						</td>
		</tr>
				<tr><td><span class='submit'><input name="uploadtheme" type="submit" value="Upload theme/backup" /></span>&nbsp;<small><strong>Upload and Restore</strong> a theme/backup from file on your computer. Will become current settings.</small></td></tr>
				<tr><td><?php if (!function_exists('aspen_pro_plugin_installed')) echo '<small>Note: Any Aspen Pro settings will <em>not</em> be restored for Aspen Free version.</small>';?>&nbsp;</td></tr>
	</table>
	<?php aspen_nonce_field('uploadtheme'); ?>
	</form>
<?php
}

function aspen_loadtheme() {
	if (!(isset($_POST['uploadit']) && $_POST['uploadit'] == 'yes')) return;

   // upload theme from users computer
	// they've supplied and uploaded a file

	$ok = true;     // no errors so far

	if (isset($_FILES['uploaded']['name']))
		$filename = $_FILES['uploaded']['name'];
	else
		$filename = "";

	if (isset($_FILES['uploaded']['tmp_name'])) {
		$openname = $_FILES['uploaded']['tmp_name'];
	} else {
		$openname = "";
	}

	//Check the file extension
	$check_file = strtolower($filename);
	$pat = '.';				// PHP version strict checking bug...
	$end = explode($pat, $check_file);
	$ext_check = end($end);


	if ($filename == "") {
		$errors[] = "You didn't select a file to upload.<br />";
		$ok = false;
	}

	if ($ok && $ext_check != 'ath' && $ext_check != 'abu'){
		$errors[] = "Theme files must have <em>.ath</em> or <em>.abu</em> extension.<br />";
		$ok = false;
	}

		if ($ok) {
			if (!aspen_f_exists($openname)) {
				$errors[] = '<strong><em style="color:red;">Sorry, there was a problem uploading your file.
		You may need to check your folder permissions or other server settings.</em></strong>'.
					"<br />(Trying to use file '$openname')";
				$ok = false;
			}
		}
	if (!$ok) {
		echo '<div id="message" class="updated fade"><p><strong><em style="color:red;">ERROR</em></strong></p><p>';
		foreach($errors as $error){
            echo $error.'<br />';
		}
		echo '</p></div>';
	} else {    // OK - read file and save to My Saved Theme
			// $handle has file handle to temp file.
			$contents = aspen_f_get_contents($openname);

			if (!aspen_ex_set_current_to_serialized_values($contents,'aspen_uploadit:'.$openname)) {
				echo '<div id="message" class="updated fade"><p><strong><em style="color:red;">Sorry,
                there was a problem uploading your file. The file you picked was not a valid
                Aspen theme file.</em></strong></p></div>';
            } else {
				aspen_save_msg('Aspen theme options reset to uploaded theme.');
			}
		}
}

function aspen_ex_set_current_to_serialized_values($contents)  {
	global $aspen_opts_cache;	// need to mess with the cache

	if (substr($contents,0,10) == 'ATH-V01.00')
        $type = 'theme';
	else if (substr($contents,0,10) == 'ABU-V01.00')
        $type = 'backup';
	else
        return aspen_f_fail(aspen_t_("Wrong theme file format version" /*a*/ )); 	/* simple check for one of ours */
	$restore = array();
	$restore = unserialize(substr($contents,10));

	if (!$restore) return aspen_f_fail("Unserialize failed");

	$version = aspen_getopt('aspen_version_id');	// get something to force load

	if ($type == 'theme') {
        // need to clear some settings
        // first, pickup the per-site settings that aren't theme related...
        $new_cache = array();
        foreach ($aspen_opts_cache as $key => $val) {
            if ($key[0] == '_')	// these are non-theme specific settings
                $new_cache[$key] = $val;	// keep
        }
        $opts = $restore['aspen_base'];	// fetch base opts
        aspen_delete_all_options();

        foreach ($opts as $key => $val) {
            if ($key[0] != '_')
                aspen_setopt($key, $val, false);	// overwrite with saved theme values
        }

        foreach ($new_cache as $key => $val) {	// set the values we need to keep
            aspen_setopt($key,$val,false);
        }
	} else if ($type == 'backup') {
        aspen_delete_all_options();

        $opts = $restore['aspen_base'];	// fetch base opts
        foreach ($opts as $key => $val) {
            aspen_setopt($key, $val, false);	// overwrite with saved values
        }
	}
	aspen_setopt('aspen_version_id',$version); // keep version, force save of db
	aspen_setopt('last_option','Aspen');
	aspen_save_opts('loading theme');	// OK, now we've saved the options, update them in the DB
	return true;
}
?>
