<?php
if ( !defined('ABSPATH')) exit; // Exit if accessed directly
/*	Aspen Theme

  This file contains all the functions needed to interact with the different
  options and settings.

  Options are saved in the WP DB in one option called 'aspen_main_settings'.

	This file includes the interface to the WP Settings API.

   Because the SAPI is quite limiting on the format of the output fields
   supported by add_settings_field, we will not use that part.

   Settings that need validation and nonce handling, we use our function aspen_sapi_main_name() that
   generates the <input name="aspen_main_settings[option_name]" ...> format required for
   processing by the sapi handlers. They create an array called $_POST['aspen_main_settings']. Each
   setting in that array corresponds to a Aspen option value, and will be passed to the
   validation function.

   We will wrap the two main forms (Main Options and most Advanced Options with our functions
   aspen_sapi_form_top() and aspen_sapi_form_bottom() that generates required calls to sapi.

   All other forms will use submit buttons that include their own nonce definition. Other forms generally
   do not change individual settings, but take actions such as save/restore or setting a subtheme.
*/


/*
	================= Main SAPI helper functions =================
*/

function aspen_sapi_form_top($group, $form_name='') {
	/* beginning of a form */
	$name = '';
	if ($form_name != '') $name = 'name="' . $form_name . '"';

	echo("<form action=\"options.php\" $name method=\"post\">\n");	/* <form action="options.php" method="post"> */
	settings_fields($group);		// use our one set of settings
}

function aspen_sapi_form_bottom($form_name='end of form') {

	$non_sapi = array(		// non-sapi elements in the db
        'aspen_version_id', 'style_version',
        'theme_filename', 'addon_name', '_hide_theme_thumbs', 'hide_advanced', 'last_option'
	);

	/*	The following code allows the SAPI to save the non-sapi values. If you don't do this here,
		then the values will be set to false, and be lost! SAPI is not tolerant of submitting a form
		that doesn't include EVERY setting for the form group. */

	foreach ($non_sapi as $name) {
?>
	<input name="<?php aspen_sapi_main_name($name); ?>" id="<?php echo $name;?>" type="hidden" value="<?php echo aspen_getopt($name); ?>" />
<?php
	}
	aspen_setopt('last_option','Aspen');	// Safety check for limited PHP $_POST variables
	echo ("</form> <!-- $form_name -->\n");
}

function aspen_sapi_submit( $before='', $after='', $show_more_opts = false ) {
	// generate a submit button for the form
	$submit_label = aspen_t_('Save Settings' /*a*/ );
	echo $before;
?>
	<span style="display:inline"><input name="save_options" type="submit" class="button-primary" value="<?php echo($submit_label); ?>" />
<?php
	echo "</span>\n" . $after ;

}

function aspen_sapi_main_name($id, $echo=true) {
	/* generate the SAPI name for 'aspen_settings' */
	$name = apply_filters('aspen_options','aspen_settings');
	if ($echo) echo $name. '[' . $id . ']';
	return $name . '[' . $id . ']';
}

/*
	============== Validation =====================
*/
function aspen_validate_all_options($in) {
	/* validation for all options  */

	$err_msg = '';			// no error message yet

	if (empty($in)) {
        wp_die( __( 'You attempted to save options, but something has gone wrong. Please be sure you are logged in and your host is correctly configured. See the "Weaver II Doesn\'t Save Settings" FAQ on weavertheme.com.' ,'weaver-ii') );
	}

	if (!current_user_can('edit_theme_options')) {
        wp_die( __( 'You do not have sufficient permissions to manage options for this site.' ,'weaver-ii') );
	}

	$wvr_last = '';

	foreach ($in as $key => $value) {
        switch ($key) {

            /* -------- integer -------- */
            case 'excerpt_length':

                if (!empty($value) && (!is_numeric($value) || !is_int((int)$value))) {
                    $opt_id = str_replace('', '', $key);
                    $opt_id = str_replace('_', ' ', $opt_id);
                    $err_msg .= aspen_t_('Option must be an integer value: ' /*a*/ ) . '"'. $opt_id . '" = "' . $value . '".'
                        . aspen_t_(' Value has been cleared to blank value' /*a*/ ) . '<br />';
                    $in[$key] = '';
                }
                break;

            /* ---------- text ----------- */
            case 'excerpt_more_msg':
            case 'header_maxwidth':

                if (!empty($value))
                    $in[$key] = aspen_filter_textarea($value);
                break;

            case 'themename':       // can't be empty!
                if (empty($value))
                    $in[$key] = 'please-give-this-a-name';
                else
                    $in[$key] = aspen_filter_textarea($value);
                break;


            /* code */

            case 'menu_addhtml':
            case '_copyright':		// Alternate copyright
            case '_css_rows':
            case 'ftp_hostname':
            case 'ftp_username':
                if (!empty($value)) {
                    $in[$key] = aspen_filter_code($value);
                }
                break;

            case 'ftp_password':		// special handling for password
                if (!empty($value)) {
                    $c_t = aspen_encrypt(trim($value));
                    $in[$key] = $c_t;
                }
                break;

            case 'perpagewidgets':       	// Add widget areas for per page - names must be lower case
                if (!empty($value)) {
                    $in[$key] = strtolower(str_ireplace(' ','',aspen_filter_code($value)));
                }
                break;

            /* must not have <style .... </style> */
            case 'add_css':              	// Add CSS Rules to Aspen's style rules

                if (!empty($value)) {
                    $val = aspen_filter_code($value);
                    $in[$key] = $val;
                    if (stripos($val,'<style') !== false || stripos($val, '</style') !== false) {
                    $err_msg .= aspen_t_('"Add CSS Rules" option must not contain &lt;style&gt; tags!' /*a*/ )
                        . aspen_t_(' Please correct your entry.' /*a*/ ) . '<br />';
                    }
                }
                break;

            case 'last_option':		// check for last_option...
                if (!empty($value))
                    $wvr_last = $value;
                break;

                case 'hide_advanced_btn':
                if (stripos($value,'hide') === false)
                    $in['hide_advanced'] = 'show';
                else
                    $in['hide_advanced'] = 'hide';
                break;

            case 'hide_advanced':
                $val = $value;
                if (isset($in['hide_advanced_btn'])) {
                    if (stripos($in['hide_advanced_btn'],'hide') === false)
                    $val = 'show';
                    else
                    $val = 'hide';
                }
                $in[$key] = $val;
                break;

            default:				/* to here, then colors, _css, or checkbox/selectors */
                $keylen = strlen($key);

                if (strrpos($key,'_css') == $keylen-4) {	// all _css settings
                    if (!empty($value)) {
                        $val = aspen_filter_code($value);
                        $in[$key] = $val;

                        if (strpos($val, '{') === false || strpos($val, '}') === false) {
                            $opt_id = str_replace('_css', '', $key);	// kill _css
                            $opt_id = str_replace('', '', $opt_id);
                            $opt_id = str_replace('_', ' ', $opt_id);
                            $err_msg .= aspen_t_('CSS options must be enclosed in {}\'s: ' /*a*/ ) . '"'. $opt_id . '" = "' . $value . '".'
                            . aspen_t_(' Please correct your entry.' /*a*/ ) . '<br />';
                        }
                    }
                    break;
                } // _css

                if (strrpos($key,'_insert') == $keylen-7) {	// all _insert settings
                    if (!empty($value)) {
                        $val = aspen_filter_code($value);
                        $in[$key] = $val;
                        }
                    break;
                } // _insert

                if (strrpos($key,'_url') == $keylen-4) {	// all _url settings
                    if (!empty($value)) {
                        $val = aspen_filter_code($value);	// can't use esc_url because that forces a leading html{background-image: url(%template_directory%images/addon_themes.png);}
                        $in[$key] = $val;
                    }
                    break;
                } // _insert

                if (strrpos($key,'_dec') == $keylen-4) {
                    if (!empty($value) && !is_numeric($value)) {
                        $opt_id = str_replace('', '', $key);
                        $opt_id = str_replace('_dec', '', $opt_id);
                        $opt_id = str_replace('_', ' ', $opt_id);
                        $err_msg .= aspen_t_('Option must be a numeric value: ' /*a*/ ) . '"'. $opt_id . '" = "' . $value . '".'
                            . aspen_t_(' Value has been cleared to blank value.' /*a*/ ) . '<br />';
                        $in[$key] = '';
                    }
                    break;
                }

                if (strrpos($key,'_int') == $keylen-4 ||	// _int settings
                    strrpos($key,'_X') == $keylen-2 ||
                    strrpos($key,'_Y') == $keylen-2 ||
                    strrpos($key,'_L') == $keylen-2 ||
                    strrpos($key,'_R') == $keylen-2 ||
                    strrpos($key,'_T') == $keylen-2 ||
                    strrpos($key,'_B') == $keylen-2 ) {
                    if (!empty($value) && (!is_numeric($value) || !is_int((int)$value))) {
                        $opt_id = str_replace('', '', $key);
                        $opt_id = str_replace('_int', '', $opt_id);
                        $opt_id = str_replace('_', ' ', $opt_id);
                        $err_msg .= aspen_t_('Option must be a numeric value: ' /*a*/ ) . '"'. $opt_id . '" = "' . $value . '".'
                            . aspen_t_(' Value has been cleared to blank value.' /*a*/ ) . '<br />';
                        $in[$key] = '';
                    }
                    break;
                }

                if (strrpos($key,'color') == $keylen-5) {	// _bgcolor and _color (order here important - after _css, etc.)
                    if (!empty($value)) {
                        $val = aspen_filter_code($value);
                        if (preg_match('/^#?+[0-9a-f]{3}(?:[0-9a-f]{3})?$/i', $val)) {	// hex value
                            $val = strtoupper($val);		// force hex values to upper case, just to be tidy
                            if ($val[0] != '#') $val = '#' . $val;
                            $in[$key] = $val;
                        } else if (preg_match("/^([a-zA-Z])+$/i", $val)) {	// name - all letters
                            $in[$key] = $val;
                        } else {		// only legal things left are rgb and rgba
                            $isrgb = strpos($val,'rgb');
                            if ($isrgb === false || $isrgb != 0) {
                                $in[$key] = '';
                                $err_msg .= 'Color must be a valid # hex value, rgb value, or color name (a-z): ' .
                                '"'. $key . '" = "' . $value . '".' . ' Value has been cleared to blank value.' . '<br />';
                            } else {
                                $in[$key] = $val;
                            }
                        }
                    }
                    break;
                }

                if (!empty($value) && is_string($value) && !is_numeric($value)) { $in[$key] = aspen_filter_textarea($value); }

                break;
        }
	}

	if ($wvr_last != 'Aspen') {
        $err_msg .= 'Warning - your host may be configured to limit how many input var options you are allowed to pass via PHP.' .
        ' Unfortunately, this means your settings may not be saved correctly. See the "Weaver II Doesn\'t Save Settings" FAQ on weavertheme.com.<br />';
	}


	if (!empty($err_msg)) {
        add_settings_error('aspen_settings', 'settings_error', $err_msg,'error');
	} else {
        add_settings_error('aspen_settings', 'settings_updated', aspen_t_('Aspen  Settings Saved.' /*a*/ ),'updated');
	}

	return $in;
}

// ========================== utils ==================================

function aspen_end_of_section($who = '') {
	if (!aspen_getopt('_hide_subtheme_link')) {
?>
	<hr /><p style="max-width:90%;"><?php aspen_site('/subthemes/'); ?><img style="max-width:95%;float:left;margin-right:10px;" src="<?php echo aspen_relative_url('/images/'); ?>theme-bar.jpg" alt="addons" />
	<strong>Discover more premium and free <br />Aspen Subthemes</strong></a>
	</p>
<?php
	}
}

function aspen_donate_button() {

	if (!aspen_getopt_checked('_hide_donate')) { ?>
<div style="float:right;padding-right:30px;"><small><strong>Like Aspen? Consider</strong></small>
<form action="https://www.paypal.com/cgi-bin/webscr" method="post">
<input type="hidden" name="cmd" value="_s-xclick">
<input type="hidden" name="hosted_button_id" value="6Y68LG9G9M82W">
<input type="image" src="https://www.paypalobjects.com/en_US/i/btn/btn_donate_LG.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online!">
<img alt="" border="0" src="https://www.paypalobjects.com/en_US/i/scr/pixel.gif" width="1" height="1">
</form>
</div>
<?php }
}

function aspen_check_theme() {
	// just check for issues...
	$level = 0;
	if ($level < 3) {	// errors
        if (aspen_getopt('wrap_shadow') && !aspen_getopt('page_bgcolor')) // MUST have wrapper page bg set
            $level = 3;
	}

	if ($level < 2) {	// warning level
        if (!is_active_sidebar('primary-widget-area') && !is_active_sidebar('right-widget-area') && !is_active_sidebar('left-widget-area'))
            $level = 2;

        $saved = get_option( apply_filters('aspen_options','aspen_settings_backup') );
        if (empty($saved)) $level = 2;

        if (aspen_getopt_checked('_development_mode')) $level = 2;
	}

	if ($level < 1) {	// advisory
        if (!function_exists('aspen_sw_installed') || !function_exists('aspen_extras_installed')) $level = 1;
        if (!aspen_getopt('_favicon_url')) $level = 1;

        if (aspen_getopt_checked('_inline_style')) $level = 1;
        if ( (strpos( aspen_getopt('_mode_mobile'), 'nostack' ) !== false) && !is_active_sidebar('mobile-widget-area')) $level = 1;

	}
?>
    <span style="float:right;margin-right:15px">
<?php
	if ($level > 0) {
?>
<form name="checkaspen_form" method="post">
	<span class="submit"><input type="submit" name="check_aspen" class="button-primary" value="Check Theme for Possible Problems"/></span>
	<?php aspen_nonce_field('check_aspen'); ?>
</form> <!-- resetaspen_form -->
<?php
	} else {
        echo '<strong>Check Theme</strong> ';
    }

	$warning = '<span style="font-weight:bold;color:green;">OK</span>';

	if ($level == 1) $warning = '<span style="font-weight:bold;color:blue;">Recommendations Available</span>';

	if ($level == 2) $warning = '<span style="font-weight:bold;color:orange;">Warnings</span>';

	if ($level == 3) $warning = '<span style="font-weight:bold;color:red;">Errors</span>';

	$msg = '';
	if ($level > 0) $msg = '<br /><span style="font-size:smaller;">Please click <em>Check Theme</em> above</span>';

	echo "<div style='margin:4px 10px 0 0;min-width:220px;'>STATUS: {$warning}{$msg}</div>";
?>
</span>
<?php
}

function aspen_clear_messages() {
?>
<form style="float:right;margin-right:15px;" name="clearaspen_form" method="post">

	<span class="submit"><input type="submit" name="aspen_clear_messages" value="Clear Messages"/></span>
	<?php aspen_nonce_field('aspen_clear_messages'); ?>
</form> <!-- resetaspen_form -->
<?php
}

function aspen_abs_file_path($http_path) {
	return untrailingslashit(ABSPATH) . parse_url($http_path,PHP_URL_PATH);
}
/*
	==================== SAVE / RESTORE THEMES AND BACKUPS ==========================
*/
function aspen_get_save_settings($is_theme) {
	// serialize current settings
	global $aspen_opts_cache;

	aspen_update_options('write_backup');

	if ($is_theme) {
        $header = 'ATH-V01.00';			/* Save theme settings: 10 byte header */
        $theme_opts = array();
        $theme_opts['aspen_base'] = $aspen_opts_cache;
        foreach ($aspen_opts_cache as $opt => $val) {
            if ($opt[0] == '_')
            $theme_opts['aspen_base'][$opt] = false;
        }
        return $header . serialize($theme_opts);	/* serialize full set of options right now */
	} else {
        $header = 'ABU-V01.00';			/* Save all settings: 10 byte header */
        $theme_opts = array();
        $theme_opts['aspen_base'] = $aspen_opts_cache;
        return $header . serialize($theme_opts);	/* serialize full set of options right now */
	}
}

function aspen_clear_cache_settings() {
	/* clear all settings */
	global $aspen_opts_cache;
	foreach ($aspen_opts_cache as $key => $value) {
        $aspen_opts_cache[$key] = false;		// clear everything
	}
}

function aspen_save_msg($msg) {
	echo '<div id="message" class="updated fade"><p><strong>' . $msg .
		'</strong></p></div>';
}
function aspen_error_msg($msg) {
	echo '<div id="message" class="updated fade" style="background:#F88;"><p><strong>' . $msg .
		'</strong></p></div>';
}

//============================================ form builder ====================================

function aspen_form_show_options($aspen_olist, $begin_table = true, $end_table = true) {
	/* output a list of options - this really does the layout for the options defined in an array */
	if ($begin_table) {
?>
<div>
<table class="optiontable" style="margin-top:6px;">
<?php
	}
	foreach ($aspen_olist as $value) {
        $value['type'] = aspen_fix_type($value['type']);
        switch ($value['type']) {
            case 'checkbox':
                aspen_form_row_checkbox($value);
                break;
            case 'ctext':
                aspen_form_row_ctext($value);
                break;
            case 'color':
                aspen_form_row_color($value);
                break;
            case 'hdr_widget':
                aspen_form_row_hdr_widget($value);
                break;
            case 'header':
                aspen_form_row_header($value);
                break;
            case 'header0':
                aspen_form_row_header($value,true);
                break;
            case 'link':
                aspen_form_row_link($value);
                break;
            case 'note':
                aspen_form_row_note($value);
                break;
            case 'selectold':
                aspen_form_row_selectold($value);
                break;
            case 'select_id':
                aspen_form_row_select_id($value);
                break;
            case 'select_layout':
                aspen_form_row_select_layout($value);
                break;
            case 'subheader':
                aspen_form_row_subheader($value);
                break;
            case 'subheader_alt':
                aspen_form_row_subheader_alt($value);
                break;
            case 'submit':
                aspen_form_row_submit($value);
                break;
            case 'text':
            case 'widetext':
                aspen_form_row_text($value);
                break;
            case 'text_xy':
                aspen_form_row_text_xy($value);
                break;
            case 'text_xy_em':
                aspen_form_row_text_xy($value,'X','Y','em');
                break;
            case 'text_xy_percent':
                aspen_form_row_text_xy($value,'X','Y','%');
                break;
            case 'text_tb':
                aspen_form_row_text_xy($value,'T','B');
                break;
            case 'text_lr':
                aspen_form_row_text_xy($value,'L','R');
                break;
            case 'textmedia':
                aspen_form_row_textarea($value,true);
                break;
            case 'textarea':
                aspen_form_row_textarea($value);
                break;
            case 'val_num':
                aspen_form_row_val($value,'');
                break;
            case 'val_percent':
                aspen_form_row_val($value,'%');
                break;
            case 'val_px':
                aspen_form_row_val($value,'px');
                break;
            case 'val_em':
                aspen_form_row_val($value,'em');
                break;
            case 'widget_area':
                aspen_form_row_widget_area($value);
                break;
            default:
                aspen_form_row_subheader_alt($value);
                break;
        }

	}
	if ($end_table) {
?>
</table></div> <!-- close previous tab div -->
	<br />
<?php
	}
}

function aspen_fix_type($type) {
	// Some options still have the + Pro or = Advanced prefixes - just strip them
	if ($type[0] == '+') {
        return substr($type,1);
	}
	if ($type[0] == '=') {
        return substr($type,1);
	}
	return $type;
}

function aspen_echo_name($value) {
	$l = $value['name'];
	if (strlen($l) > 4 && $l[0] == '#') {
        echo '<span style="color:' . substr($l,0,4) .
            ';">' . substr($l,4) . '</span>';
	} else {
        echo $l;
	}
}

function aspen_form_row_ctext($value) {

	$pclass = 'color {hash:true, adjust:false}';    // starting with V 1.3, allow text in color pickers
	$img_css = '<img src="'. esc_url(get_template_directory_uri() . '/images/theme/css.png') . '" alt="css" />' ;
	$img_hide = esc_url(get_template_directory_uri() . '/images/theme/hide.png') ;
	$img_show = esc_url(get_template_directory_uri() . '/images/theme/show.png') ;
	$help_file = esc_url(get_template_directory_uri() . '/help/css-help.html');
	$css_id = $value['id'] . '_css';
	$css_id_text = aspen_getopt($css_id);
	if ($css_id_text && !aspen_getopt( '_hide_auto_css_rules' )) {
        $img_toggle = $img_hide;
	} else {
        $img_toggle = $img_show;
	}
?>
	<tr>
	<th scope="row" align="right"><?php aspen_echo_name($value); ?>:&nbsp;</th>
	<td>
	<input class="<?php echo $pclass; ?>" name="<?php aspen_sapi_main_name($value['id']); ?>" id="<?php echo $value['id']; ?>" type="text" style="width:90px" value="<?php if ( aspen_getopt( $value['id'] ) != "") { aspen_esc_textarea(aspen_getopt( $value['id'] )); } else { echo ''; } ?>" />
<?php
echo $img_css; ?><a href="javascript:void(null);" onclick="aspen_ToggleRowCSS(document.getElementById('<?php echo $css_id . '_js'; ?>'), this, '<?php echo $img_show; ?>', '<?php echo $img_hide; ?>')"><?php echo '<img src="' . esc_url($img_toggle) . '" alt="toggle css" />'; ?></a>
	</td>
<?php 	aspen_form_row_info($value);
?>
	</tr>
<?php
	$css_rows = aspen_getopt('_css_rows');
	if ($css_rows < 1 || $css_rows > 25)
        $css_rows = 1;
	if ($css_id_text && !aspen_getopt( '_hide_auto_css_rules' )) { ?>
	<tr id="<?php echo $css_id . '_js'; ?>">
	<th scope="row" align="right"><span style="color:#22a;"><small>Custom CSS styling:</small></span></th>
	<td align="right"><small>&nbsp;</small></td>
	<td>
		<small>You can enter CSS rules, enclosed in {}'s, and separated by <strong>;</strong>.
		See <a href="<?php echo $help_file; ?>" target="_blank">CSS Help</a> for more details.</small><br />
		<textarea name="<?php aspen_sapi_main_name($css_id); ?>" rows=<?php echo $css_rows;?> style="width: 85%"><?php aspen_esc_textarea($css_id_text); ?></textarea>
	</td>
	</tr>
<?php
	} else {
?>
	<tr id="<?php echo $css_id . '_js'; ?>" style="display:none;">
	<th scope="row" align="right"><span style="color:green;"><small>Custom CSS styling:</small></span></th>
	<td align="right"><small>&nbsp;</small></td>
	<td>
		<small>You can enter CSS rules, enclosed in {}'s, and separated by <strong>;</strong>.
		See <a href="<?php echo $help_file; ?>" target="_blank">CSS Help</a> for more details.</small><br />
		<textarea name="<?php aspen_sapi_main_name($css_id); ?>" rows=<?php echo $css_rows;?> style="width: 85%"><?php aspen_esc_textarea($css_id_text); ?></textarea>
	</td>
	</tr>
<?php
	}
}

function aspen_form_row_hdr_widget($value) {
	$name = $value['name'];
	$val['name'] = $name . ' Widget BG';
	$val['id'] = $value['id'] . '_bgcolor';
	$val['type'] = 'ctext';
	$val['info'] = 'Background color for ' . $name . ' widget.';
	aspen_form_row_ctext($val);

	$val['name'] = $name . ' Widget Width';
	$val['id'] = $value['id'] . '_w_int';
	$val['type'] = 'val_pc';
	$val['info'] = 'Width of ' . $name . ' widget. (Use 0 to hide. Allows different widgets on regular and mobile views.)';
	aspen_form_row_val($val,'%');

	$val['name'] = '<small>' . $name . ' Widget Mobile Width</small>';
	$val['id'] = $value['id'] . '_w_mobile_int';
	$val['type'] = 'val_pc';
	$val['info'] = 'Width of ' . $name . ' widget on mobile devices. (Use 0 to hide. Allows different widgets on regular and mobile views.)';
	aspen_form_row_val($val,'%');
}

function aspen_form_row_color($value) {

	$pclass = 'color {hash:true, adjust:false}';    // starting with V 1.3, allow text in color pickers
?>
	<tr>
	<th scope="row" align="right"><?php aspen_echo_name($value); ?>:&nbsp;</th>
	<td>
	<input class="<?php echo $pclass; ?>" name="<?php aspen_sapi_main_name($value['id']); ?>" id="<?php echo $value['id']; ?>" type="text" style="width:90px" value="<?php if ( aspen_getopt( $value['id'] ) != "") { aspen_esc_textarea(aspen_getopt( $value['id'] )); } else { echo ''; } ?>" />
	</td>
<?php 	aspen_form_row_info($value);
?>
	</tr>
<?php
}

function aspen_form_row_header($value,$narrow=false) {
?>
	<tr class="atw-row-header">
	<th scope="row" align="left" style="width:200px;"><?php	/* NO SAPI SETTING */
	echo '<span style="font-weight:bold; font-size: larger;"><em>'.$value['name'].'</em></span>';
		aspen_form_help($value);
?>
	</th>
<?php
	if ($narrow) echo ('<td  style="width:80px;">&nbsp;</td>'. "\n");
	else echo ('<td style="width:170px;">&nbsp;</td>'. "\n");

	if ($value['info'] != '') {
		echo('<td style="padding-left: 10px"><u><em><strong>'); echo $value['info'];
		echo("</strong></em></u></td>\n");
	}
?>
	</tr>
<?php
}

function aspen_form_help($value) {
	if (!empty($value['help'])) {
        aspen_help_link($value['help'], 'Help for ' . $value['name']);
    }
}

function aspen_form_row_subheader($value) {
?>
	<tr class="atw-row-subheader">
	<th scope="row" align="left" style="width:200px;line-height:2em;"><?php	/* NO SAPI SETTING */
	echo '<span style="color:blue; font-weight:bold; "><em><u>'.$value['name'].'</u></em></span>';
	aspen_form_help($value);
?>
	</th>
	<td style="width:170px;">&nbsp;</td>
<?php
	if ($value['info'] != '') {
		echo('<td style="padding-left: 10px"><u><em>'); echo $value['info'];
		echo("</em></u></td>\n");
	}
?>
	</tr>
<?php
}

function aspen_form_row_subheader_alt($value) {
?>
	<tr class="atw-row-subheader-alt">
	<th scope="row" align="left" style="width:200px;line-height:2em;"><?php	/* NO SAPI SETTING */
	echo '<span style="color:blue; font-weight:bold;padding-left:15px;"><em>'.$value['name'].'</em></span>';
	aspen_form_help($value);
?>
	</th>
	<td style="width:170px;">&nbsp;</td>
<?php
	if ($value['info'] != '') {
		echo('<td style="padding-left: 10px;color:blue;">'); echo $value['info'];
		echo("</td>\n");
	}
?>
	</tr>
<?php
}

function aspen_form_row_textarea($value,$media = false) {
	$twide =  ($value['type'] == 'text') ? '60' : '140';
?>
	<tr>
	<th scope="row" align="right"><?php aspen_echo_name($value); ?>:&nbsp;</th>
	<td colspan=2>
		<textarea name="<?php aspen_sapi_main_name($value['id']); ?>" id="<?php echo $value['id']; ?>" rows=1 style="width: 350px"><?php echo(esc_textarea( aspen_getopt($value['id'] ))); ?></textarea>
<?php
	if ($media) {
	aspen_media_lib_button($value['id']);
	}
?>
&nbsp;<small><?php echo $value['info']; ?></small>
	</td>

	</tr>
<?php
}

function aspen_form_row_text($value,$media=false) {
	$twide =  ($value['type'] == 'text') ? '60' : '140';
?>
	<tr>
	<th scope="row" align="right"><?php aspen_echo_name($value); ?>:&nbsp;</th>
	<td>
		<input name="<?php aspen_sapi_main_name($value['id']); ?>" id="<?php echo $value['id']; ?>" type="text" style="width:<?php echo $twide;?>px;height:22px;" class="regular-text" value="<?php echo esc_textarea(aspen_getopt( $value['id'] )); ?>" />
<?php
	if ($media) {
	   aspen_media_lib_button($value['id']);
	}
?>
	</td>
<?php	aspen_form_row_info($value);
?>
	</tr>
<?php
}

function aspen_form_row_val($value,$unit) {
?>
	<tr>
	<th scope="row" align="right"><?php aspen_echo_name($value); ?>:&nbsp;</th>
	<td>
		<input name="<?php aspen_sapi_main_name($value['id']); ?>" id="<?php echo $value['id']; ?>" type="text" style="width:50px;height:22px;" class="regular-text" value="<?php echo esc_textarea(aspen_getopt( $value['id'] )); ?>" /> <?php echo $unit; ?>
	</td>
<?php	aspen_form_row_info($value);
?>
	</tr>
<?php
}

function aspen_form_row_text_xy($value,$x='X',$y='Y',$units='px') {
	$xid = $value['id'] . '_' . $x;
	$yid = $value['id'] . '_' . $y;
?>
	<tr>
	<th scope="row" align="right"><?php aspen_echo_name($value); ?>:&nbsp;</th>
	<td>
		<?php echo $x;?>:<input name="<?php aspen_sapi_main_name($xid); ?>" id="<?php echo $xid; ?>" type="text" style="width:40px;height:20px;" class="regular-text" value="<?php aspen_esc_textarea(aspen_getopt( $xid )); ?>" /> <?php echo $units; ?>
		&nbsp;<?php echo $y;?>:<input name="<?php aspen_sapi_main_name($yid); ?>" id="<?php echo $yid; ?>" type="text" style="width:40px;height:20px;" class="regular-text" value="<?php aspen_esc_textarea(aspen_getopt( $yid )); ?>" /> <?php echo $units; ?>
	</td>
<?php	aspen_form_row_info($value);
?>
	</tr>
<?php
}

function aspen_form_row_checkbox($value) {
?>
	<tr>
	<th scope="row" align="right"><?php aspen_echo_name($value); ?>:&nbsp;</th>
	<td>
	<input type="checkbox" name="<?php aspen_sapi_main_name($value['id']); ?>" id="<?php echo $value['id']; ?>"
<?php 		checked(aspen_getopt_checked( $value['id'] )); ?> >
	</td>
<?php 	aspen_form_row_info($value);
?>
	</tr>
<?php
}

function aspen_form_row_selectold($value) {
?>
	<tr>
	<th scope="row" align="right"><?php aspen_echo_name($value); ?>:&nbsp;</th>
	<td>
	<select name="<?php aspen_sapi_main_name($value['id']); ?>" id="<?php echo $value['id']; ?>">
<?php 	foreach ($value['value'] as $option) { ?>
			<option<?php selected( ( aspen_getopt( $value['id'] ) == $option));?>><?php echo $option; ?></option>
<?php 	} ?>
	</select>
	</td>
<?php 	aspen_form_row_info($value);
?>
	</tr>
<?php
}

function aspen_form_row_select_id($value) {
?>
	<tr>
	<th scope="row" align="right"><?php aspen_echo_name($value); ?>:&nbsp;</th>
	<td>
	<select name="<?php aspen_sapi_main_name($value['id']); ?>" id="<?php echo $value['id']; ?>">
<?php
	foreach ($value['value'] as $option) {
	?>
			<option value="<?php echo $option['val'] ?>" <?php selected( (aspen_getopt( $value['id'] ) == $option['val']));?>><?php echo $option['desc']; ?></option>
<?php 	} ?>
	</select>
	</td>
<?php 	aspen_form_row_info($value);
?>
	</tr>
<?php
}
function aspen_form_row_select_layout($value) {
	$list = array(array('val' => 'default', 'desc'=> 'Use Default' ),
	array('val' => 'right-1-col', 'desc'=> 'Single column sidebar on Right' ),
	array('val' => 'left-1-col', 'desc' => 'Single column sidebar on Left'),
	array('val' => 'right-2-col', 'desc' => 'Double Cols, Right (top wide)'),
	array('val' => 'left-2-col', 'desc' => 'Double Cols, Left (top wide)'),
	array('val' => 'right-2-col-bottom', 'desc' => 'Double Cols, Right (bottom wide)'),
	array('val' => 'left-2-col-bottom', 'desc' => 'Double Cols, Left (bottom wide)'),
	array('val' => 'split', 'desc' => 'Split - sidebars on Right and Left'),
	array('val' => 'one-column', 'desc' => 'No sidebars, one column content')
	);
	$value['value'] = $list;
	aspen_form_row_select_id($value);
}

function aspen_form_row_link($value) {
	$link = array ('name' => '<small>Link</small>', 'id' => $value['id'].'_color', 'type' => 'ctext', 'info' => 'Color of link');
	$strong = array ('name' => '<small>Bold</small>', 'id' => $value['id'].'_strong', 'type' => 'checkbox', 'info' => '<strong>Bold</strong> link');
	$em = array ('name' => '<small>Italic</small>', 'id' => $value['id'].'_em', 'type' => 'checkbox', 'info' => '<em>Italic</em> link');
	$visit = array ('name' => '<small>Visited</small>', 'id' => $value['id'].'_visited_color', 'type' => 'ctext', 'info' => 'Color when link has been visited (this option is generally falling out of use)');
	$hover = array ('name' => '<small>Hover</small>', 'id' => $value['id'].'_hover_color', 'type' => 'ctext', 'info' => 'Color when hovering');
	$under = array ('name' => '<small>Underline</small>', 'id' => $value['id'].'_u', 'type' => 'checkbox', 'info' => '<u>Underline</u> on hover');

	aspen_form_row_subheader_alt($value);
	aspen_form_row_ctext($link);
	aspen_form_row_checkbox($strong);
	aspen_form_row_checkbox($em);
	aspen_form_row_ctext($visit);
	aspen_form_row_ctext($hover);
	aspen_form_row_checkbox($under);

}


function aspen_form_row_note($value) {
?>
	<tr>
	<th scope="row" align="right">&nbsp;</th>
		<td style="float:right;font-weight:bold;"><?php aspen_echo_name($value); ?>&nbsp;
<?php
	aspen_form_help($value);
?>
		</td>
<?php
	aspen_form_row_info($value);
?>
	</tr>
<?php
}

function aspen_form_row_submit($value) {
	aspen_sapi_submit('</table>','<table style="margin-top:10px;">');
}

function aspen_form_row_info($value) {
	if ($value['info'] != '') {
	echo('<td style="padding-left: 10px"><small>'); echo $value['info']; echo("</small></td>");
	}
}

function aspen_form_row_widget_area($value) {
	// build the rows for widget area settings
	/*
	Primary Sidebar Widget Area
	Background
	Left/Right Padding
	Top/Bottom Padding
	Top/Bottom Margin
	Border
*/
	$name = $value['name']; $id = $value['id'];
	$row = array('name' => '', 'id' => '', 'type' => '', 'info' => '');
	aspen_form_row_subheader_alt($value);
	$row['name'] = 'Background'; $row['id'] = $id . '_bgcolor'; $row['info'] = $name . ': Background Color (use CSS+ to specify custom borders!)';
	aspen_form_row_ctext($row);
	$row['name'] = 'Top/Bottom Margins'; $row['id'] = $id . '_margin'; $row['info'] = $name . ': Top and bottom margin';
	aspen_form_row_text_xy($row,'T','B');
	$row['name'] = '<small>Add Border</small>'; $row['id'] = $id . '_std_border'; $row['info'] = $name . ': Add the "standard" border (as set on General Appearance tab)';
	aspen_form_row_checkbox($row);
}

?>
